@@ -2,7 +2,6 @@
 
 from sqlspec import adapters, base, builder, core, driver, exceptions, extensions, loader, migrations, typing, utils
 from sqlspec.__metadata__ import __version__
-from sqlspec._sql import SQLFactory, sql
 from sqlspec.base import SQLSpec
 from sqlspec.builder import (
     Column,
@@ -15,7 +14,9 @@ from sqlspec.builder import (
     Merge,
     QueryBuilder,
     Select,
+    SQLFactory,
     Update,
+    sql,
 )
 from sqlspec.config import AsyncDatabaseConfig, SyncDatabaseConfig
 from sqlspec.core import (
@@ -34,16 +35,10 @@ from sqlspec.core import (
 from sqlspec.core import filters as filters
 from sqlspec.driver import AsyncDriverAdapterBase, ExecutionResult, SyncDriverAdapterBase
 from sqlspec.loader import SQLFile, SQLFileLoader
-from sqlspec.typing import (
-    ConnectionT,
-    DictRow,
-    ModelDTOT,
-    ModelT,
-    PoolT,
-    RowT,
-    StatementParameters,
-    SupportedSchemaModel,
-)
+from sqlspec.typing import ConnectionT, PoolT, SchemaT, StatementParameters, SupportedSchemaModel
+from sqlspec.utils.logging import suppress_erroneous_sqlglot_log_messages
+
+suppress_erroneous_sqlglot_log_messages()
 
 __all__ = (
     "SQL",
@@ -57,26 +52,23 @@ __all__ = (
     "ConnectionT",
     "CreateTable",
     "Delete",
-    "DictRow",
     "DropTable",
     "ExecutionResult",
     "FunctionColumn",
     "Insert",
     "Merge",
-    "ModelDTOT",
-    "ModelT",
     "ParameterConverter",
     "ParameterProcessor",
     "ParameterStyle",
     "ParameterStyleConfig",
     "PoolT",
     "QueryBuilder",
-    "RowT",
     "SQLFactory",
     "SQLFile",
     "SQLFileLoader",
     "SQLResult",
     "SQLSpec",
+    "SchemaT",
     "Select",
     "Statement",
     "StatementConfig",
