@@ -2,6 +2,9 @@
 
 Provides a Protocol-based serialization system that users can extend.
 Supports msgspec, orjson, and standard library JSON with automatic fallback.
+
+Features optional numpy array serialization when numpy is installed.
+Arrays are automatically converted to lists during JSON encoding.
 """
 
 import contextlib
@@ -9,19 +12,25 @@ import datetime
 import enum
 import json
 from abc import ABC, abstractmethod
-from typing import Any, Final, Literal, Optional, Protocol, Union, overload
+from typing import Any, Final, Literal, Protocol, overload
 
+from sqlspec._typing import NUMPY_INSTALLED
 from sqlspec.typing import MSGSPEC_INSTALLED, ORJSON_INSTALLED, PYDANTIC_INSTALLED, BaseModel
 
 
-def _type_to_string(value: Any) -> str:  # pragma: no cover
+def _type_to_string(value: Any) -> Any:  # pragma: no cover
     """Convert special types to strings for JSON serialization.
 
+    Handles datetime, date, enums, Pydantic models, and numpy arrays.
+
     Args:
         value: Value to convert.
 
     Returns:
-        String representation of the value.
+        Serializable representation of the value (string, list, dict, etc.).
+
+    Raises:
+        TypeError: If value cannot be serialized.
     """
     if isinstance(value, datetime.datetime):
         return convert_datetime_to_gmt_iso(value)
@@ -31,10 +40,16 @@ def _type_to_string(value: Any) -> str:  # pragma: no cover
         return str(value.value)
     if PYDANTIC_INSTALLED and isinstance(value, BaseModel):
         return value.model_dump_json()
+    if NUMPY_INSTALLED:
+        import numpy as np
+
+        if isinstance(value, np.ndarray):
+            return value.tolist()
     try:
         return str(value)
     except Exception as exc:
-        raise TypeError from exc
+        msg = f"Cannot serialize {type(value).__name__}"
+        raise TypeError(msg) from exc
 
 
 class JSONSerializer(Protocol):
@@ -43,7 +58,7 @@ class JSONSerializer(Protocol):
     Users can implement this protocol to create custom serializers.
     """
 
-    def encode(self, data: Any, *, as_bytes: bool = False) -> Union[str, bytes]:
+    def encode(self, data: Any, *, as_bytes: bool = False) -> str | bytes:
         """Encode data to JSON.
 
         Args:
@@ -55,7 +70,7 @@ class JSONSerializer(Protocol):
         """
         ...
 
-    def decode(self, data: Union[str, bytes], *, decode_bytes: bool = True) -> Any:
+    def decode(self, data: str | bytes, *, decode_bytes: bool = True) -> Any:
         """Decode from JSON.
 
         Args:
@@ -74,18 +89,18 @@ class BaseJSONSerializer(ABC):
     __slots__ = ()
 
     @abstractmethod
-    def encode(self, data: Any, *, as_bytes: bool = False) -> Union[str, bytes]:
+    def encode(self, data: Any, *, as_bytes: bool = False) -> str | bytes:
         """Encode data to JSON."""
         ...
 
     @abstractmethod
-    def decode(self, data: Union[str, bytes], *, decode_bytes: bool = True) -> Any:
+    def decode(self, data: str | bytes, *, decode_bytes: bool = True) -> Any:
         """Decode from JSON."""
         ...
 
 
 class MsgspecSerializer(BaseJSONSerializer):
-    """Msgspec-based JSON serializer for optimal performance."""
+    """Msgspec-based JSON serializer."""
 
     __slots__ = ("_decoder", "_encoder")
 
@@ -96,7 +111,7 @@ class MsgspecSerializer(BaseJSONSerializer):
         self._encoder: Final[Encoder] = Encoder(enc_hook=_type_to_string)
         self._decoder: Final[Decoder] = Decoder()
 
-    def encode(self, data: Any, *, as_bytes: bool = False) -> Union[str, bytes]:
+    def encode(self, data: Any, *, as_bytes: bool = False) -> str | bytes:
         """Encode data using msgspec."""
         try:
             if as_bytes:
@@ -107,7 +122,7 @@ class MsgspecSerializer(BaseJSONSerializer):
                 return OrjsonSerializer().encode(data, as_bytes=as_bytes)
             return StandardLibSerializer().encode(data, as_bytes=as_bytes)
 
-    def decode(self, data: Union[str, bytes], *, decode_bytes: bool = True) -> Any:
+    def decode(self, data: str | bytes, *, decode_bytes: bool = True) -> Any:
         """Decode data using msgspec."""
         if isinstance(data, bytes):
             if decode_bytes:
@@ -128,25 +143,40 @@ class MsgspecSerializer(BaseJSONSerializer):
 
 
 class OrjsonSerializer(BaseJSONSerializer):
-    """Orjson-based JSON serializer with native datetime/UUID support."""
+    """Orjson-based JSON serializer with native datetime/UUID support.
+
+    Automatically enables numpy serialization if numpy is installed.
+    """
 
     __slots__ = ()
 
-    def encode(self, data: Any, *, as_bytes: bool = False) -> Union[str, bytes]:
-        """Encode data using orjson."""
+    def encode(self, data: Any, *, as_bytes: bool = False) -> str | bytes:
+        """Encode data using orjson.
+
+        Args:
+            data: Data to encode.
+            as_bytes: Whether to return bytes instead of string.
+
+        Returns:
+            JSON string or bytes depending on as_bytes parameter.
+        """
         from orjson import (
             OPT_NAIVE_UTC,  # pyright: ignore[reportUnknownVariableType]
-            OPT_SERIALIZE_NUMPY,  # pyright: ignore[reportUnknownVariableType]
             OPT_SERIALIZE_UUID,  # pyright: ignore[reportUnknownVariableType]
         )
         from orjson import dumps as _orjson_dumps  # pyright: ignore[reportMissingImports]
 
-        result = _orjson_dumps(
-            data, default=_type_to_string, option=OPT_SERIALIZE_NUMPY | OPT_NAIVE_UTC | OPT_SERIALIZE_UUID
-        )
+        options = OPT_NAIVE_UTC | OPT_SERIALIZE_UUID
+
+        if NUMPY_INSTALLED:
+            from orjson import OPT_SERIALIZE_NUMPY  # pyright: ignore[reportUnknownVariableType]
+
+            options |= OPT_SERIALIZE_NUMPY
+
+        result = _orjson_dumps(data, default=_type_to_string, option=options)
         return result if as_bytes else result.decode("utf-8")
 
-    def decode(self, data: Union[str, bytes], *, decode_bytes: bool = True) -> Any:
+    def decode(self, data: str | bytes, *, decode_bytes: bool = True) -> Any:
         """Decode data using orjson."""
         from orjson import loads as _orjson_loads  # pyright: ignore[reportMissingImports]
 
@@ -162,12 +192,12 @@ class StandardLibSerializer(BaseJSONSerializer):
 
     __slots__ = ()
 
-    def encode(self, data: Any, *, as_bytes: bool = False) -> Union[str, bytes]:
+    def encode(self, data: Any, *, as_bytes: bool = False) -> str | bytes:
         """Encode data using standard library json."""
         json_str = json.dumps(data, default=_type_to_string)
         return json_str.encode("utf-8") if as_bytes else json_str
 
-    def decode(self, data: Union[str, bytes], *, decode_bytes: bool = True) -> Any:
+    def decode(self, data: str | bytes, *, decode_bytes: bool = True) -> Any:
         """Decode data using standard library json."""
         if isinstance(data, bytes):
             if decode_bytes:
@@ -176,7 +206,7 @@ class StandardLibSerializer(BaseJSONSerializer):
         return json.loads(data)
 
 
-_default_serializer: Optional[JSONSerializer] = None
+_default_serializer: JSONSerializer | None = None
 
 
 def get_default_serializer() -> JSONSerializer:
@@ -213,8 +243,8 @@ def encode_json(data: Any, *, as_bytes: Literal[False] = ...) -> str: ...  # pra
 def encode_json(data: Any, *, as_bytes: Literal[True]) -> bytes: ...  # pragma: no cover
 
 
-def encode_json(data: Any, *, as_bytes: bool = False) -> Union[str, bytes]:
-    """Encode to JSON, optionally returning bytes for optimal performance.
+def encode_json(data: Any, *, as_bytes: bool = False) -> str | bytes:
+    """Encode to JSON, optionally returning bytes.
 
     Args:
         data: The data to encode.
@@ -226,7 +256,7 @@ def encode_json(data: Any, *, as_bytes: bool = False) -> Union[str, bytes]:
     return get_default_serializer().encode(data, as_bytes=as_bytes)
 
 
-def decode_json(data: Union[str, bytes], *, decode_bytes: bool = True) -> Any:
+def decode_json(data: str | bytes, *, decode_bytes: bool = True) -> Any:
     """Decode from JSON string or bytes efficiently.
 
     Args:
