@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING
 from adbc_driver_manager.dbapi import Connection
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
+    from typing import TypeAlias
 
     AdbcConnection: TypeAlias = Connection
 else:
