@@ -1,6 +1,6 @@
 """AsyncPG adapter for SQLSpec."""
 
-from sqlspec.adapters.asyncpg._types import AsyncpgConnection
+from sqlspec.adapters.asyncpg._types import AsyncpgConnection, AsyncpgPool
 from sqlspec.adapters.asyncpg.config import AsyncpgConfig, AsyncpgConnectionConfig, AsyncpgPoolConfig
 from sqlspec.adapters.asyncpg.driver import (
     AsyncpgCursor,
@@ -16,6 +16,7 @@ __all__ = (
     "AsyncpgCursor",
     "AsyncpgDriver",
     "AsyncpgExceptionHandler",
+    "AsyncpgPool",
     "AsyncpgPoolConfig",
     "asyncpg_statement_config",
 )
