@@ -3,7 +3,7 @@ from typing import TYPE_CHECKING
 from google.cloud.bigquery import Client
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
+    from typing import TypeAlias
 
     BigQueryConnection: TypeAlias = Client
 else:
