@@ -1,9 +1,9 @@
 from typing import TYPE_CHECKING
 
-from duckdb import DuckDBPyConnection  # type: ignore[import-untyped]
+from duckdb import DuckDBPyConnection
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
+    from typing import TypeAlias
 
     DuckDBConnection: TypeAlias = DuckDBPyConnection
 else:
