@@ -3,7 +3,7 @@
 
 import re
 from contextlib import suppress
-from typing import TYPE_CHECKING, Callable, Optional, cast
+from typing import TYPE_CHECKING, Any, cast
 
 from sqlspec.driver import (
     AsyncDataDictionaryBase,
@@ -15,6 +15,8 @@ from sqlspec.driver import (
 from sqlspec.utils.logging import get_logger
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     from sqlspec.adapters.oracledb.driver import OracleAsyncDriver, OracleSyncDriver
 
 logger = get_logger("adapters.oracledb.data_dictionary")
@@ -35,12 +37,7 @@ class OracleVersionInfo(VersionInfo):
     """Oracle database version information."""
 
     def __init__(
-        self,
-        major: int,
-        minor: int = 0,
-        patch: int = 0,
-        compatible: "Optional[str]" = None,
-        is_autonomous: bool = False,
+        self, major: int, minor: int = 0, patch: int = 0, compatible: "str | None" = None, is_autonomous: bool = False
     ) -> None:
         """Initialize Oracle version info.
 
@@ -56,7 +53,7 @@ class OracleVersionInfo(VersionInfo):
         self.is_autonomous = is_autonomous
 
     @property
-    def compatible_major(self) -> "Optional[int]":
+    def compatible_major(self) -> "int | None":
         """Get major version from compatible parameter."""
         if not self.compatible:
             return None
@@ -109,7 +106,31 @@ class OracleDataDictionaryMixin:
 
     __slots__ = ()
 
-    def _get_oracle_version(self, driver: "OracleAsyncDriver | OracleSyncDriver") -> "Optional[OracleVersionInfo]":
+    def _get_columns_sql(self, table: str, schema: "str | None" = None) -> str:
+        """Get SQL to query column metadata from Oracle data dictionary.
+
+        Uses USER_TAB_COLUMNS which returns column names in UPPERCASE.
+
+        Args:
+            table: Table name to query columns for
+            schema: Schema name (unused for USER_TAB_COLUMNS)
+
+        Returns:
+            SQL string for Oracle's USER_TAB_COLUMNS query
+        """
+        _ = schema
+        return f"""
+            SELECT
+                column_name AS "column_name",
+                data_type AS "data_type",
+                data_length AS "data_length",
+                nullable AS "nullable"
+            FROM user_tab_columns
+            WHERE table_name = '{table.upper()}'
+            ORDER BY column_id
+        """
+
+    def _get_oracle_version(self, driver: "OracleAsyncDriver | OracleSyncDriver") -> "OracleVersionInfo | None":
         """Get Oracle database version information.
 
         Args:
@@ -118,7 +139,7 @@ class OracleDataDictionaryMixin:
         Returns:
             Oracle version information or None if detection fails
         """
-        banner = driver.select_value("SELECT banner FROM v$version WHERE banner LIKE 'Oracle%'")
+        banner = driver.select_value("SELECT banner AS \"banner\" FROM v$version WHERE banner LIKE 'Oracle%'")
 
         # Parse version from banner like "Oracle Database 21c Enterprise Edition Release 21.0.0.0.0 - Production"
         # or "Oracle Database 19c Standard Edition 2 Release 19.0.0.0.0 - Production"
@@ -143,7 +164,7 @@ class OracleDataDictionaryMixin:
         logger.debug("Detected Oracle version: %s", version_info)
         return version_info
 
-    def _get_oracle_compatible(self, driver: "OracleAsyncDriver | OracleSyncDriver") -> "Optional[str]":
+    def _get_oracle_compatible(self, driver: "OracleAsyncDriver | OracleSyncDriver") -> "str | None":
         """Get Oracle compatible parameter value.
 
         Args:
@@ -153,14 +174,14 @@ class OracleDataDictionaryMixin:
             Compatible parameter value or None if detection fails
         """
         try:
-            compatible = driver.select_value("SELECT value FROM v$parameter WHERE name = 'compatible'")
+            compatible = driver.select_value("SELECT value AS \"value\" FROM v$parameter WHERE name = 'compatible'")
             logger.debug("Detected Oracle compatible parameter: %s", compatible)
             return str(compatible)
         except Exception:
             logger.warning("Compatible parameter not found")
             return None
 
-    def _get_oracle_json_type(self, version_info: "Optional[OracleVersionInfo]") -> str:
+    def _get_oracle_json_type(self, version_info: "OracleVersionInfo | None") -> str:
         """Determine the appropriate JSON column type for Oracle.
 
         Args:
@@ -199,10 +220,10 @@ class OracleSyncDataDictionary(OracleDataDictionaryMixin, SyncDataDictionaryBase
         Returns:
             True if this is an Autonomous Database, False otherwise
         """
-        result = driver.select_value_or_none("SELECT COUNT(*) as cnt FROM v$pdbs WHERE cloud_identity IS NOT NULL")
+        result = driver.select_value_or_none('SELECT COUNT(1) AS "cnt" FROM v$pdbs WHERE cloud_identity IS NOT NULL')
         return bool(result and int(result) > 0)
 
-    def get_version(self, driver: SyncDriverAdapterBase) -> "Optional[OracleVersionInfo]":
+    def get_version(self, driver: SyncDriverAdapterBase) -> "OracleVersionInfo | None":
         """Get Oracle database version information.
 
         Args:
@@ -275,6 +296,28 @@ class OracleSyncDataDictionary(OracleDataDictionaryMixin, SyncDataDictionaryBase
         }
         return type_map.get(type_category, "VARCHAR2(255)")
 
+    def get_columns(
+        self, driver: SyncDriverAdapterBase, table: str, schema: "str | None" = None
+    ) -> "list[dict[str, Any]]":
+        """Get column information for a table from Oracle data dictionary.
+
+        Args:
+            driver: Database driver instance
+            table: Table name to query columns for
+            schema: Schema name (ignored for USER_TAB_COLUMNS)
+
+        Returns:
+            List of column metadata dictionaries with keys:
+                - column_name: Name of the column
+                - data_type: Oracle data type
+                - data_length: Maximum length (for character types)
+                - nullable: 'Y' or 'N'
+        """
+
+        oracle_driver = cast("OracleSyncDriver", driver)
+        result = oracle_driver.execute(self._get_columns_sql(table, schema))
+        return result.get_data()
+
     def list_available_features(self) -> "list[str]":
         """List available Oracle feature flags.
 
@@ -296,7 +339,7 @@ class OracleSyncDataDictionary(OracleDataDictionaryMixin, SyncDataDictionaryBase
 class OracleAsyncDataDictionary(OracleDataDictionaryMixin, AsyncDataDictionaryBase):
     """Oracle-specific async data dictionary."""
 
-    async def get_version(self, driver: AsyncDriverAdapterBase) -> "Optional[OracleVersionInfo]":
+    async def get_version(self, driver: AsyncDriverAdapterBase) -> "OracleVersionInfo | None":
         """Get Oracle database version information.
 
         Args:
@@ -306,7 +349,7 @@ class OracleAsyncDataDictionary(OracleDataDictionaryMixin, AsyncDataDictionaryBa
             Oracle version information or None if detection fails
         """
         banner = await cast("OracleAsyncDriver", driver).select_value(
-            "SELECT banner FROM v$version WHERE banner LIKE 'Oracle%'"
+            "SELECT banner AS \"banner\" FROM v$version WHERE banner LIKE 'Oracle%'"
         )
 
         version_match = ORACLE_VERSION_PATTERN.search(str(banner))
@@ -336,7 +379,7 @@ class OracleAsyncDataDictionary(OracleDataDictionaryMixin, AsyncDataDictionaryBa
         logger.debug("Detected Oracle version: %s", version_info)
         return version_info
 
-    async def _get_oracle_compatible_async(self, driver: "OracleAsyncDriver") -> "Optional[str]":
+    async def _get_oracle_compatible_async(self, driver: "OracleAsyncDriver") -> "str | None":
         """Get Oracle compatible parameter value (async version).
 
         Args:
@@ -346,7 +389,9 @@ class OracleAsyncDataDictionary(OracleDataDictionaryMixin, AsyncDataDictionaryBa
             Compatible parameter value or None if detection fails
         """
         try:
-            compatible = await driver.select_value("SELECT value FROM v$parameter WHERE name = 'compatible'")
+            compatible = await driver.select_value(
+                "SELECT value AS \"value\" FROM v$parameter WHERE name = 'compatible'"
+            )
             logger.debug("Detected Oracle compatible parameter: %s", compatible)
             return str(compatible)
         except Exception:
@@ -364,7 +409,7 @@ class OracleAsyncDataDictionary(OracleDataDictionaryMixin, AsyncDataDictionaryBa
         """
         # Check for cloud_identity in v$pdbs (most reliable for Autonomous)
         with suppress(Exception):
-            result = await driver.execute("SELECT COUNT(*) as cnt FROM v$pdbs WHERE cloud_identity IS NOT NULL")
+            result = await driver.execute('SELECT COUNT(1) AS "cnt" FROM v$pdbs WHERE cloud_identity IS NOT NULL')
             if result.data:
                 count = result.data[0]["cnt"] if isinstance(result.data[0], dict) else result.data[0][0]
                 if int(count) > 0:
@@ -424,6 +469,28 @@ class OracleAsyncDataDictionary(OracleDataDictionaryMixin, AsyncDataDictionaryBa
         type_map = {"uuid": "RAW(16)", "boolean": "NUMBER(1)", "timestamp": "TIMESTAMP", "text": "CLOB", "blob": "BLOB"}
         return type_map.get(type_category, "VARCHAR2(255)")
 
+    async def get_columns(
+        self, driver: AsyncDriverAdapterBase, table: str, schema: "str | None" = None
+    ) -> "list[dict[str, Any]]":
+        """Get column information for a table from Oracle data dictionary.
+
+        Args:
+            driver: Async database driver instance
+            table: Table name to query columns for
+            schema: Schema name (ignored for USER_TAB_COLUMNS)
+
+        Returns:
+            List of column metadata dictionaries with keys:
+                - column_name: Name of the column
+                - data_type: Oracle data type
+                - data_length: Maximum length (for character types)
+                - nullable: 'Y' or 'N'
+        """
+
+        oracle_driver = cast("OracleAsyncDriver", driver)
+        result = await oracle_driver.execute(self._get_columns_sql(table, schema))
+        return result.get_data()
+
     def list_available_features(self) -> "list[str]":
         """List available Oracle feature flags.
 
