@@ -3,7 +3,7 @@
 import logging
 from collections.abc import AsyncGenerator
 from contextlib import asynccontextmanager
-from typing import TYPE_CHECKING, Any, ClassVar, Optional, TypedDict, Union
+from typing import TYPE_CHECKING, Any, ClassVar, TypedDict
 
 from psqlpy import ConnectionPool
 from typing_extensions import NotRequired
@@ -12,6 +12,7 @@ from sqlspec.adapters.psqlpy._types import PsqlpyConnection
 from sqlspec.adapters.psqlpy.driver import PsqlpyCursor, PsqlpyDriver, psqlpy_statement_config
 from sqlspec.config import AsyncDatabaseConfig
 from sqlspec.core.statement import StatementConfig
+from sqlspec.typing import PGVECTOR_INSTALLED
 
 if TYPE_CHECKING:
     from collections.abc import Callable
@@ -20,7 +21,7 @@ if TYPE_CHECKING:
 logger = logging.getLogger("sqlspec.adapters.psqlpy")
 
 
-class PsqlpyConnectionParams(TypedDict, total=False):
+class PsqlpyConnectionParams(TypedDict):
     """Psqlpy connection parameters."""
 
     dsn: NotRequired[str]
@@ -62,7 +63,7 @@ class PsqlpyConnectionParams(TypedDict, total=False):
     load_balance_hosts: NotRequired[str]
 
 
-class PsqlpyPoolParams(PsqlpyConnectionParams, total=False):
+class PsqlpyPoolParams(PsqlpyConnectionParams):
     """Psqlpy pool parameters."""
 
     hosts: NotRequired[list[str]]
@@ -73,7 +74,19 @@ class PsqlpyPoolParams(PsqlpyConnectionParams, total=False):
     extra: NotRequired[dict[str, Any]]
 
 
-__all__ = ("PsqlpyConfig", "PsqlpyConnectionParams", "PsqlpyCursor", "PsqlpyPoolParams")
+class PsqlpyDriverFeatures(TypedDict):
+    """Psqlpy driver feature flags.
+
+    enable_pgvector: Enable automatic pgvector extension support for vector similarity search.
+        Requires pgvector-python package installed.
+        Defaults to True when pgvector is installed.
+        Provides automatic conversion between NumPy arrays and PostgreSQL vector types.
+    """
+
+    enable_pgvector: NotRequired[bool]
+
+
+__all__ = ("PsqlpyConfig", "PsqlpyConnectionParams", "PsqlpyCursor", "PsqlpyDriverFeatures", "PsqlpyPoolParams")
 
 
 class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyDriver]):
@@ -81,38 +94,47 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
 
     driver_type: ClassVar[type[PsqlpyDriver]] = PsqlpyDriver
     connection_type: "ClassVar[type[PsqlpyConnection]]" = PsqlpyConnection
+    supports_transactional_ddl: "ClassVar[bool]" = True
 
     def __init__(
         self,
         *,
-        pool_config: Optional[Union[PsqlpyPoolParams, dict[str, Any]]] = None,
-        pool_instance: Optional[ConnectionPool] = None,
-        migration_config: Optional[dict[str, Any]] = None,
-        statement_config: Optional[StatementConfig] = None,
-        driver_features: Optional[dict[str, Any]] = None,
-        bind_key: Optional[str] = None,
+        pool_config: PsqlpyPoolParams | dict[str, Any] | None = None,
+        pool_instance: ConnectionPool | None = None,
+        migration_config: dict[str, Any] | None = None,
+        statement_config: StatementConfig | None = None,
+        driver_features: "PsqlpyDriverFeatures | dict[str, Any] | None" = None,
+        bind_key: str | None = None,
+        extension_config: "dict[str, dict[str, Any]] | None" = None,
     ) -> None:
         """Initialize Psqlpy configuration.
 
         Args:
-            pool_config: Pool configuration parameters
-            pool_instance: Existing connection pool instance to use
-            migration_config: Migration configuration
-            statement_config: SQL statement configuration
-            driver_features: Driver feature configuration
-            bind_key: Optional unique identifier for this configuration
+            pool_config: Pool configuration parameters.
+            pool_instance: Existing connection pool instance to use.
+            migration_config: Migration configuration.
+            statement_config: SQL statement configuration.
+            driver_features: Driver feature configuration (TypedDict or dict).
+            bind_key: Optional unique identifier for this configuration.
+            extension_config: Extension-specific configuration (e.g., Litestar plugin settings).
         """
         processed_pool_config: dict[str, Any] = dict(pool_config) if pool_config else {}
         if "extra" in processed_pool_config:
             extras = processed_pool_config.pop("extra")
             processed_pool_config.update(extras)
+
+        processed_driver_features: dict[str, Any] = dict(driver_features) if driver_features else {}
+        if "enable_pgvector" not in processed_driver_features:
+            processed_driver_features["enable_pgvector"] = PGVECTOR_INSTALLED
+
         super().__init__(
             pool_config=processed_pool_config,
             pool_instance=pool_instance,
             migration_config=migration_config,
             statement_config=statement_config or psqlpy_statement_config,
-            driver_features=driver_features or {},
+            driver_features=processed_driver_features,
             bind_key=bind_key,
+            extension_config=extension_config,
         )
 
     def _get_pool_config_dict(self) -> dict[str, Any]:
@@ -185,7 +207,7 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
 
     @asynccontextmanager
     async def provide_session(
-        self, *args: Any, statement_config: "Optional[StatementConfig]" = None, **kwargs: Any
+        self, *args: Any, statement_config: "StatementConfig | None" = None, **kwargs: Any
     ) -> AsyncGenerator[PsqlpyDriver, None]:
         """Provide an async driver session context manager.
 
@@ -198,7 +220,11 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
             A PsqlpyDriver instance.
         """
         async with self.provide_connection(*args, **kwargs) as conn:
-            yield self.driver_type(connection=conn, statement_config=statement_config or self.statement_config)
+            yield self.driver_type(
+                connection=conn,
+                statement_config=statement_config or self.statement_config,
+                driver_features=self.driver_features,
+            )
 
     async def provide_pool(self, *args: Any, **kwargs: Any) -> ConnectionPool:
         """Provide async pool instance.
