@@ -2,7 +2,7 @@ import sqlite3
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
+    from typing import TypeAlias
 
     SqliteConnection: TypeAlias = sqlite3.Connection
 else:
