@@ -3,12 +3,15 @@ import inspect
 import sys
 from collections.abc import Sequence
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, cast
+
+import rich_click as click
 
 if TYPE_CHECKING:
-    from click import Group
+    from rich_click import Group
 
     from sqlspec.config import AsyncDatabaseConfig, SyncDatabaseConfig
+    from sqlspec.migrations.commands import AsyncMigrationCommands, SyncMigrationCommands
 
 __all__ = ("add_migration_commands", "get_sqlspec_group")
 
@@ -16,21 +19,9 @@ __all__ = ("add_migration_commands", "get_sqlspec_group")
 def get_sqlspec_group() -> "Group":
     """Get the SQLSpec CLI group.
 
-    Raises:
-        MissingDependencyError: If the `click` package is not installed.
-
     Returns:
         The SQLSpec CLI group.
     """
-    from sqlspec.exceptions import MissingDependencyError
-
-    try:
-        import rich_click as click
-    except ImportError:
-        try:
-            import click  # type: ignore[no-redef]
-        except ImportError as e:
-            raise MissingDependencyError(package="click", install_package="cli") from e
 
     @click.group(name="sqlspec")
     @click.option(
@@ -89,27 +80,15 @@ def get_sqlspec_group() -> "Group":
     return sqlspec_group
 
 
-def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
+def add_migration_commands(database_group: "Group | None" = None) -> "Group":
     """Add migration commands to the database group.
 
     Args:
         database_group: The database group to add the commands to.
 
-    Raises:
-        MissingDependencyError: If the `click` package is not installed.
-
     Returns:
         The database group with the migration commands added.
     """
-    from sqlspec.exceptions import MissingDependencyError
-
-    try:
-        import rich_click as click
-    except ImportError:
-        try:
-            import click  # type: ignore[no-redef]
-        except ImportError as e:
-            raise MissingDependencyError(package="click", install_package="cli") from e
     from rich import get_console
 
     console = get_console()
@@ -145,10 +124,16 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
         default="auto",
         help="Force execution mode (auto-detects by default)",
     )
+    no_auto_sync_option = click.option(
+        "--no-auto-sync",
+        is_flag=True,
+        default=False,
+        help="Disable automatic version reconciliation when migrations have been renamed",
+    )
 
     def get_config_by_bind_key(
-        ctx: "click.Context", bind_key: Optional[str]
-    ) -> "Union[AsyncDatabaseConfig[Any, Any, Any], SyncDatabaseConfig[Any, Any, Any]]":
+        ctx: "click.Context", bind_key: str | None
+    ) -> "AsyncDatabaseConfig[Any, Any, Any] | SyncDatabaseConfig[Any, Any, Any]":
         """Get the SQLSpec config for the specified bind key.
 
         Args:
@@ -173,13 +158,7 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
                 console.print(f"[red]No config found for bind key: {bind_key}[/]")
                 sys.exit(1)
 
-        # Extract the actual config from DatabaseConfig wrapper if needed
-        from sqlspec.extensions.litestar.config import DatabaseConfig
-
-        if isinstance(config, DatabaseConfig):
-            config = config.config
-
-        return cast("Union[AsyncDatabaseConfig[Any, Any, Any], SyncDatabaseConfig[Any, Any, Any]]", config)
+        return cast("AsyncDatabaseConfig[Any, Any, Any] | SyncDatabaseConfig[Any, Any, Any]", config)
 
     def get_configs_with_migrations(ctx: "click.Context", enabled_only: bool = False) -> "list[tuple[str, Any]]":
         """Get all configurations that have migrations enabled.
@@ -194,18 +173,13 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
         configs = ctx.obj["configs"]
         migration_configs = []
 
-        from sqlspec.extensions.litestar.config import DatabaseConfig
-
         for config in configs:
-            # Extract the actual config from DatabaseConfig wrapper if needed
-            actual_config = config.config if isinstance(config, DatabaseConfig) else config
-
-            migration_config = actual_config.migration_config
+            migration_config = config.migration_config
             if migration_config:
                 enabled = migration_config.get("enabled", True)
                 if not enabled_only or enabled:
-                    config_name = actual_config.bind_key or str(type(actual_config).__name__)
-                    migration_configs.append((config_name, actual_config))
+                    config_name = config.bind_key or str(type(config).__name__)
+                    migration_configs.append((config_name, config))
 
         return migration_configs
 
@@ -237,12 +211,12 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
 
     def process_multiple_configs(
         ctx: "click.Context",
-        bind_key: Optional[str],
+        bind_key: str | None,
         include: "tuple[str, ...]",
         exclude: "tuple[str, ...]",
         dry_run: bool,
         operation_name: str,
-    ) -> "Optional[list[tuple[str, Any]]]":
+    ) -> "list[tuple[str, Any]] | None":
         """Process configuration selection for multi-config operations.
 
         Args:
@@ -290,7 +264,7 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
     @include_option
     @exclude_option
     def show_database_revision(  # pyright: ignore[reportUnusedFunction]
-        bind_key: Optional[str], verbose: bool, include: "tuple[str, ...]", exclude: "tuple[str, ...]"
+        bind_key: str | None, verbose: bool, include: "tuple[str, ...]", exclude: "tuple[str, ...]"
     ) -> None:
         """Show current database revision."""
         from sqlspec.migrations.commands import create_migration_commands
@@ -318,7 +292,9 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
                 for config_name, config in configs_to_process:
                     console.print(f"\n[blue]Configuration: {config_name}[/]")
                     try:
-                        migration_commands = create_migration_commands(config=config)
+                        migration_commands: SyncMigrationCommands[Any] | AsyncMigrationCommands[Any] = (
+                            create_migration_commands(config=config)
+                        )
                         await maybe_await(migration_commands.current(verbose=verbose))
                     except Exception as e:
                         console.print(f"[red]✗ Failed to get current revision for {config_name}: {e}[/]")
@@ -338,7 +314,7 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
     @dry_run_option
     @click.argument("revision", type=str, default="-1")
     def downgrade_database(  # pyright: ignore[reportUnusedFunction]
-        bind_key: Optional[str],
+        bind_key: str | None,
         revision: str,
         no_prompt: bool,
         include: "tuple[str, ...]",
@@ -379,8 +355,10 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
                 for config_name, config in configs_to_process:
                     console.print(f"[blue]Downgrading configuration: {config_name}[/]")
                     try:
-                        migration_commands = create_migration_commands(config=config)
-                        await maybe_await(migration_commands.downgrade(revision=revision))
+                        migration_commands: SyncMigrationCommands[Any] | AsyncMigrationCommands[Any] = (
+                            create_migration_commands(config=config)
+                        )
+                        await maybe_await(migration_commands.downgrade(revision=revision, dry_run=dry_run))
                         console.print(f"[green]✓ Successfully downgraded: {config_name}[/]")
                     except Exception as e:
                         console.print(f"[red]✗ Failed to downgrade {config_name}: {e}[/]")
@@ -395,7 +373,7 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
                 if input_confirmed:
                     sqlspec_config = get_config_by_bind_key(cast("click.Context", ctx), bind_key)
                     migration_commands = create_migration_commands(config=sqlspec_config)
-                    await maybe_await(migration_commands.downgrade(revision=revision))
+                    await maybe_await(migration_commands.downgrade(revision=revision, dry_run=dry_run))
 
         run_(_downgrade_database)()
 
@@ -406,15 +384,17 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
     @exclude_option
     @dry_run_option
     @execution_mode_option
+    @no_auto_sync_option
     @click.argument("revision", type=str, default="head")
     def upgrade_database(  # pyright: ignore[reportUnusedFunction]
-        bind_key: Optional[str],
+        bind_key: str | None,
         revision: str,
         no_prompt: bool,
         include: "tuple[str, ...]",
         exclude: "tuple[str, ...]",
         dry_run: bool,
         execution_mode: str,
+        no_auto_sync: bool,
     ) -> None:
         """Upgrade the database to the latest revision."""
         from rich.prompt import Confirm
@@ -449,8 +429,12 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
                 for config_name, config in configs_to_process:
                     console.print(f"[blue]Upgrading configuration: {config_name}[/]")
                     try:
-                        migration_commands = create_migration_commands(config=config)
-                        await maybe_await(migration_commands.upgrade(revision=revision))
+                        migration_commands: SyncMigrationCommands[Any] | AsyncMigrationCommands[Any] = (
+                            create_migration_commands(config=config)
+                        )
+                        await maybe_await(
+                            migration_commands.upgrade(revision=revision, auto_sync=not no_auto_sync, dry_run=dry_run)
+                        )
                         console.print(f"[green]✓ Successfully upgraded: {config_name}[/]")
                     except Exception as e:
                         console.print(f"[red]✗ Failed to upgrade {config_name}: {e}[/]")
@@ -467,14 +451,16 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
                 if input_confirmed:
                     sqlspec_config = get_config_by_bind_key(cast("click.Context", ctx), bind_key)
                     migration_commands = create_migration_commands(config=sqlspec_config)
-                    await maybe_await(migration_commands.upgrade(revision=revision))
+                    await maybe_await(
+                        migration_commands.upgrade(revision=revision, auto_sync=not no_auto_sync, dry_run=dry_run)
+                    )
 
         run_(_upgrade_database)()
 
     @database_group.command(help="Stamp the revision table with the given revision")
     @click.argument("revision", type=str)
     @bind_key_option
-    def stamp(bind_key: Optional[str], revision: str) -> None:  # pyright: ignore[reportUnusedFunction]
+    def stamp(bind_key: str | None, revision: str) -> None:  # pyright: ignore[reportUnusedFunction]
         """Stamp the revision table with the given revision."""
         from sqlspec.migrations.commands import create_migration_commands
         from sqlspec.utils.sync_tools import run_
@@ -494,12 +480,11 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
     @click.option("--package", is_flag=True, default=True, help="Create `__init__.py` for created folder")
     @no_prompt_option
     def init_sqlspec(  # pyright: ignore[reportUnusedFunction]
-        bind_key: Optional[str], directory: Optional[str], package: bool, no_prompt: bool
+        bind_key: str | None, directory: str | None, package: bool, no_prompt: bool
     ) -> None:
         """Initialize the database migrations."""
         from rich.prompt import Confirm
 
-        from sqlspec.extensions.litestar.config import DatabaseConfig
         from sqlspec.migrations.commands import create_migration_commands
         from sqlspec.utils.sync_tools import run_
 
@@ -520,23 +505,23 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
                 )
 
                 for config in configs:
-                    # Extract the actual config from DatabaseConfig wrapper if needed
-                    actual_config = config.config if isinstance(config, DatabaseConfig) else config
-                    migration_config = getattr(actual_config, "migration_config", {})
+                    migration_config = getattr(config, "migration_config", {})
                     target_directory = (
-                        migration_config.get("script_location", "migrations") if directory is None else directory
+                        str(migration_config.get("script_location", "migrations")) if directory is None else directory
                     )
-                    migration_commands = create_migration_commands(config=actual_config)
-                    await maybe_await(migration_commands.init(directory=cast("str", target_directory), package=package))
+                    migration_commands = create_migration_commands(config=config)
+                    await maybe_await(migration_commands.init(directory=target_directory, package=package))
 
         run_(_init_sqlspec)()
 
-    @database_group.command(name="make-migrations", help="Create a new migration revision.")
+    @database_group.command(
+        name="create-migration", aliases=["make-migration"], help="Create a new migration revision."
+    )
     @bind_key_option
     @click.option("-m", "--message", default=None, help="Revision message")
     @no_prompt_option
     def create_revision(  # pyright: ignore[reportUnusedFunction]
-        bind_key: Optional[str], message: Optional[str], no_prompt: bool
+        bind_key: str | None, message: str | None, no_prompt: bool
     ) -> None:
         """Create a new database revision."""
         from rich.prompt import Prompt
@@ -560,9 +545,31 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
 
         run_(_create_revision)()
 
+    @database_group.command(name="fix", help="Convert timestamp migrations to sequential format.")
+    @bind_key_option
+    @dry_run_option
+    @click.option("--yes", is_flag=True, help="Skip confirmation prompt")
+    @click.option("--no-database", is_flag=True, help="Skip database record updates")
+    def fix_migrations(  # pyright: ignore[reportUnusedFunction]
+        bind_key: str | None, dry_run: bool, yes: bool, no_database: bool
+    ) -> None:
+        """Convert timestamp migrations to sequential format."""
+        from sqlspec.migrations.commands import create_migration_commands
+        from sqlspec.utils.sync_tools import run_
+
+        ctx = click.get_current_context()
+
+        async def _fix_migrations() -> None:
+            console.rule("[yellow]Migration Fix Command[/]", align="left")
+            sqlspec_config = get_config_by_bind_key(cast("click.Context", ctx), bind_key)
+            migration_commands = create_migration_commands(config=sqlspec_config)
+            await maybe_await(migration_commands.fix(dry_run=dry_run, update_database=not no_database, yes=yes))
+
+        run_(_fix_migrations)()
+
     @database_group.command(name="show-config", help="Show all configurations with migrations enabled.")
     @bind_key_option
-    def show_config(bind_key: Optional[str] = None) -> None:  # pyright: ignore[reportUnusedFunction]
+    def show_config(bind_key: str | None = None) -> None:  # pyright: ignore[reportUnusedFunction]
         """Show and display all configurations with migrations enabled."""
         from rich.table import Table
 
@@ -593,7 +600,7 @@ def add_migration_commands(database_group: Optional["Group"] = None) -> "Group":
         for config_name, config in migration_configs:
             migration_config = getattr(config, "migration_config", {})
             script_location = migration_config.get("script_location", "migrations")
-            table.add_row(config_name, script_location, "Migration Enabled")
+            table.add_row(config_name, str(script_location), "Migration Enabled")
 
         console.print(table)
         console.print(f"[blue]Found {len(migration_configs)} configuration(s) with migrations enabled.[/]")
