@@ -1,7 +1,5 @@
 """Driver protocols and base classes for database adapters."""
 
-from typing import Union
-
 from sqlspec.driver import mixins
 from sqlspec.driver._async import AsyncDataDictionaryBase, AsyncDriverAdapterBase
 from sqlspec.driver._common import CommonDriverAttributesMixin, ExecutionResult, VersionInfo
@@ -19,4 +17,4 @@ __all__ = (
     "mixins",
 )
 
-DriverAdapterProtocol = Union[SyncDriverAdapterBase, AsyncDriverAdapterBase]
+DriverAdapterProtocol = SyncDriverAdapterBase | AsyncDriverAdapterBase
