@@ -1,15 +1,24 @@
 from collections.abc import Generator
 from contextlib import contextmanager
-from typing import Any, Optional, Union
+from typing import Any
 
 __all__ = (
+    "CheckViolationError",
     "ConfigResolverError",
+    "DataError",
+    "DatabaseConnectionError",
     "FileNotFoundInStorageError",
+    "ForeignKeyViolationError",
     "ImproperConfigurationError",
     "IntegrityError",
+    "InvalidVersionFormatError",
+    "MigrationError",
     "MissingDependencyError",
     "MultipleResultsFoundError",
     "NotFoundError",
+    "NotNullViolationError",
+    "OperationalError",
+    "OutOfOrderMigrationError",
     "RepositoryError",
     "SQLBuilderError",
     "SQLConversionError",
@@ -19,6 +28,8 @@ __all__ = (
     "SQLSpecError",
     "SerializationError",
     "StorageOperationFailedError",
+    "TransactionError",
+    "UniqueViolationError",
 )
 
 
@@ -55,7 +66,7 @@ class SQLSpecError(Exception):
 class MissingDependencyError(SQLSpecError, ImportError):
     """Raised when a required dependency is not installed."""
 
-    def __init__(self, package: str, install_package: Optional[str] = None) -> None:
+    def __init__(self, package: str, install_package: str | None = None) -> None:
         super().__init__(
             f"Package {package!r} is not installed but required. You can install it by running "
             f"'pip install sqlspec[{install_package or package}]' to install sqlspec with the required extra "
@@ -77,7 +88,7 @@ class ConfigResolverError(SQLSpecError):
 class SQLParsingError(SQLSpecError):
     """Issues parsing SQL statements."""
 
-    def __init__(self, message: Optional[str] = None) -> None:
+    def __init__(self, message: str | None = None) -> None:
         if message is None:
             message = "Issues parsing SQL statement."
         super().__init__(message)
@@ -86,7 +97,7 @@ class SQLParsingError(SQLSpecError):
 class SQLBuilderError(SQLSpecError):
     """Issues Building or Generating SQL statements."""
 
-    def __init__(self, message: Optional[str] = None) -> None:
+    def __init__(self, message: str | None = None) -> None:
         if message is None:
             message = "Issues building SQL statement."
         super().__init__(message)
@@ -95,7 +106,7 @@ class SQLBuilderError(SQLSpecError):
 class SQLConversionError(SQLSpecError):
     """Issues converting SQL statements."""
 
-    def __init__(self, message: Optional[str] = None) -> None:
+    def __init__(self, message: str | None = None) -> None:
         if message is None:
             message = "Issues converting SQL statement."
         super().__init__(message)
@@ -125,6 +136,38 @@ class MultipleResultsFoundError(RepositoryError):
     """A single database result was required but more than one were found."""
 
 
+class UniqueViolationError(IntegrityError):
+    """A unique constraint was violated."""
+
+
+class ForeignKeyViolationError(IntegrityError):
+    """A foreign key constraint was violated."""
+
+
+class CheckViolationError(IntegrityError):
+    """A check constraint was violated."""
+
+
+class NotNullViolationError(IntegrityError):
+    """A not-null constraint was violated."""
+
+
+class DatabaseConnectionError(SQLSpecError):
+    """Database connection error (invalid credentials, network failure, etc.)."""
+
+
+class TransactionError(SQLSpecError):
+    """Transaction error (rollback, deadlock, serialization failure)."""
+
+
+class DataError(SQLSpecError):
+    """Invalid data type or format for database operation."""
+
+
+class OperationalError(SQLSpecError):
+    """Operational database error (timeout, disk full, resource limit)."""
+
+
 class StorageOperationFailedError(SQLSpecError):
     """Raised when a storage backend operation fails (e.g., network, permission, API error)."""
 
@@ -136,7 +179,7 @@ class FileNotFoundInStorageError(StorageOperationFailedError):
 class SQLFileNotFoundError(SQLSpecError):
     """Raised when a SQL file cannot be found."""
 
-    def __init__(self, name: str, path: "Optional[str]" = None) -> None:
+    def __init__(self, name: str, path: "str | None" = None) -> None:
         """Initialize the error.
 
         Args:
@@ -167,9 +210,29 @@ class SQLFileParseError(SQLSpecError):
         self.original_error = original_error
 
 
+class MigrationError(SQLSpecError):
+    """Base exception for migration-related errors."""
+
+
+class InvalidVersionFormatError(MigrationError):
+    """Raised when a migration version format is invalid.
+
+    Invalid formats include versions that don't match sequential (0001)
+    or timestamp (YYYYMMDDHHmmss) patterns, or timestamps with invalid dates.
+    """
+
+
+class OutOfOrderMigrationError(MigrationError):
+    """Raised when an out-of-order migration is detected in strict mode.
+
+    Out-of-order migrations occur when a pending migration has a timestamp
+    earlier than already-applied migrations, typically from late-merging branches.
+    """
+
+
 @contextmanager
 def wrap_exceptions(
-    wrap_exceptions: bool = True, suppress: "Optional[Union[type[Exception], tuple[type[Exception], ...]]]" = None
+    wrap_exceptions: bool = True, suppress: "type[Exception] | tuple[type[Exception], ...] | None" = None
 ) -> Generator[None, None, None]:
     """Context manager for exception handling with optional suppression.
 
