@@ -1,9 +1,9 @@
 # pyright: ignore[reportAttributeAccessIssue]
-from collections.abc import Iterator, Mapping
+from collections.abc import Iterator
 from functools import lru_cache
-from typing import TYPE_CHECKING, Annotated, Any, Protocol, Union
+from typing import Annotated, Any, Protocol, TypeAlias, _TypedDict  # pyright: ignore
 
-from typing_extensions import TypeAlias, TypeVar
+from typing_extensions import TypeVar
 
 from sqlspec._typing import (
     AIOSQL_INSTALLED,
@@ -16,17 +16,22 @@ from sqlspec._typing import (
     OBSTORE_INSTALLED,
     OPENTELEMETRY_INSTALLED,
     ORJSON_INSTALLED,
+    PANDAS_INSTALLED,
     PGVECTOR_INSTALLED,
+    POLARS_INSTALLED,
     PROMETHEUS_INSTALLED,
     PYARROW_INSTALLED,
     PYDANTIC_INSTALLED,
     UNSET,
     AiosqlAsyncProtocol,
     AiosqlParamType,
-    AiosqlProtocol,
     AiosqlSQLOperationType,
     AiosqlSyncProtocol,
     ArrowRecordBatch,
+    ArrowRecordBatchReader,
+    ArrowRecordBatchReaderProtocol,
+    ArrowSchema,
+    ArrowSchemaProtocol,
     ArrowTable,
     AttrsInstance,
     AttrsInstanceStub,
@@ -41,6 +46,9 @@ from sqlspec._typing import (
     FailFast,
     Gauge,
     Histogram,
+    NumpyArray,
+    PandasDataFrame,
+    PolarsDataFrame,
     Span,
     Status,
     StatusCode,
@@ -61,9 +69,6 @@ from sqlspec._typing import (
     trace,
 )
 
-if TYPE_CHECKING:
-    from collections.abc import Sequence
-
 
 class DictLike(Protocol):
     """A protocol for objects that behave like a dictionary for reading."""
@@ -87,30 +92,22 @@ PoolT = TypeVar("PoolT")
 
 :class:`~sqlspec.typing.PoolT`
 """
-PoolT_co = TypeVar("PoolT_co", covariant=True)
-"""Type variable for covariant pool types.
+SchemaT = TypeVar("SchemaT", default=dict[str, Any])
+"""Type variable for schema types (models, TypedDict, dataclasses, etc.).
 
-:class:`~sqlspec.typing.PoolT_co`
+Unbounded TypeVar for use with schema_type parameter in driver methods.
+Supports all schema types including TypedDict which cannot be bounded to a class hierarchy.
 """
-ModelT = TypeVar("ModelT", bound="Union[DictLike, StructStub, BaseModelStub, DataclassProtocol, AttrsInstanceStub]")
-"""Type variable for model types.
-
-:class:`DictLike` | :class:`msgspec.Struct` | :class:`pydantic.BaseModel` | :class:`DataclassProtocol` | :class:`AttrsInstance`
-"""
-RowT = TypeVar("RowT", bound="dict[str, Any]")
 
 
-DictRow: TypeAlias = "dict[str, Any]"
-"""Type variable for DictRow types."""
-TupleRow: TypeAlias = "tuple[Any, ...]"
-"""Type variable for TupleRow types."""
-
-SupportedSchemaModel: TypeAlias = "Union[DictLike, StructStub, BaseModelStub, DataclassProtocol, AttrsInstanceStub]"
+SupportedSchemaModel: TypeAlias = (
+    DictLike | StructStub | BaseModelStub | DataclassProtocol | AttrsInstanceStub | _TypedDict
+)
 """Type alias for pydantic or msgspec models.
 
 :class:`msgspec.Struct` | :class:`pydantic.BaseModel` | :class:`DataclassProtocol` | :class:`AttrsInstance`
 """
-StatementParameters: TypeAlias = "Union[Any, dict[str, Any], list[Any], tuple[Any, ...], None]"
+StatementParameters: TypeAlias = "Any | dict[str, Any] | list[Any] | tuple[Any, ...] | None"
 """Type alias for statement parameters.
 
 Represents:
@@ -119,40 +116,6 @@ Represents:
 - :type:`tuple[Any, ...]`
 - :type:`None`
 """
-ModelDTOT = TypeVar("ModelDTOT", bound="SupportedSchemaModel")
-"""Type variable for model DTOs.
-
-:class:`msgspec.Struct`|:class:`pydantic.BaseModel`
-"""
-PydanticOrMsgspecT = SupportedSchemaModel
-"""Type alias for pydantic or msgspec models.
-
-:class:`msgspec.Struct` or :class:`pydantic.BaseModel`
-"""
-ModelDict: TypeAlias = (
-    "Union[dict[str, Any], Union[DictLike, StructStub, BaseModelStub, DataclassProtocol, AttrsInstanceStub], Any]"
-)
-"""Type alias for model dictionaries.
-
-Represents:
-- :type:`dict[str, Any]` | :class:`DataclassProtocol` | :class:`msgspec.Struct` |  :class:`pydantic.BaseModel`
-"""
-ModelDictList: TypeAlias = (
-    "Sequence[Union[dict[str, Any], Union[DictLike, StructStub, BaseModelStub, DataclassProtocol, AttrsInstanceStub]]]"
-)
-"""Type alias for model dictionary lists.
-
-A list or sequence of any of the following:
-- :type:`Sequence`[:type:`dict[str, Any]` | :class:`DataclassProtocol` | :class:`msgspec.Struct` | :class:`pydantic.BaseModel`]
-
-"""
-BulkModelDict: TypeAlias = "Union[Sequence[Union[dict[str, Any], Union[DictLike, StructStub, BaseModelStub, DataclassProtocol, AttrsInstanceStub]]], Any]"
-"""Type alias for bulk model dictionaries.
-
-Represents:
-- :type:`Sequence`[:type:`dict[str, Any]` | :class:`DataclassProtocol` | :class:`msgspec.Struct` | :class:`pydantic.BaseModel`]
-- :class:`DTOData`[:type:`list[ModelT]`]
-"""
 
 
 @lru_cache(typed=True)
@@ -170,18 +133,6 @@ def get_type_adapter(f: "type[T]") -> Any:
     return TypeAdapter(f)
 
 
-def MixinOf(base: type[T]) -> type[T]:  # noqa: N802
-    """Useful function to make mixins with baseclass type hint
-
-    ```
-    class StorageMixin(MixinOf(DriverProtocol)): ...
-    ```
-    """
-    if TYPE_CHECKING:
-        return base
-    return type("<MixinOf>", (base,), {})
-
-
 __all__ = (
     "AIOSQL_INSTALLED",
     "ATTRS_INSTALLED",
@@ -193,7 +144,9 @@ __all__ = (
     "OBSTORE_INSTALLED",
     "OPENTELEMETRY_INSTALLED",
     "ORJSON_INSTALLED",
+    "PANDAS_INSTALLED",
     "PGVECTOR_INSTALLED",
+    "POLARS_INSTALLED",
     "PROMETHEUS_INSTALLED",
     "PYARROW_INSTALLED",
     "PYDANTIC_INSTALLED",
@@ -201,38 +154,32 @@ __all__ = (
     "UNSET",
     "AiosqlAsyncProtocol",
     "AiosqlParamType",
-    "AiosqlProtocol",
     "AiosqlSQLOperationType",
     "AiosqlSyncProtocol",
     "ArrowRecordBatch",
+    "ArrowRecordBatchReader",
+    "ArrowRecordBatchReaderProtocol",
+    "ArrowSchema",
+    "ArrowSchemaProtocol",
     "ArrowTable",
     "AttrsInstance",
     "BaseModel",
-    "BulkModelDict",
     "ConnectionT",
     "Counter",
     "DTOData",
     "DataclassProtocol",
     "DictLike",
-    "DictRow",
     "Empty",
     "EmptyEnum",
     "EmptyType",
     "FailFast",
     "Gauge",
     "Histogram",
-    "Mapping",
-    "MixinOf",
-    "ModelDTOT",
-    "ModelDict",
-    "ModelDict",
-    "ModelDictList",
-    "ModelDictList",
-    "ModelT",
+    "NumpyArray",
+    "PandasDataFrame",
+    "PolarsDataFrame",
     "PoolT",
-    "PoolT_co",
-    "PydanticOrMsgspecT",
-    "RowT",
+    "SchemaT",
     "Span",
     "StatementParameters",
     "Status",
@@ -240,7 +187,6 @@ __all__ = (
     "Struct",
     "SupportedSchemaModel",
     "Tracer",
-    "TupleRow",
     "TypeAdapter",
     "UnsetType",
     "aiosql",
