@@ -17,6 +17,7 @@ from pytest_databases.docker.mysql import MySQLService
 from sqlspec.adapters.asyncmy import AsyncmyConfig, AsyncmyDriver, asyncmy_statement_config
 from sqlspec.core.result import SQLResult
 from sqlspec.core.statement import SQL
+from sqlspec.utils.serializers import from_json, to_json
 
 ParamStyle = Literal["tuple_binds", "dict_binds", "named_binds"]
 
@@ -61,7 +62,6 @@ async def asyncmy_session(mysql_service: MySQLService) -> AsyncGenerator[Asyncmy
         yield session
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_basic_crud(asyncmy_driver: AsyncmyDriver) -> None:
     """Test basic CRUD operations."""
     driver = asyncmy_driver
@@ -89,7 +89,6 @@ async def test_asyncmy_basic_crud(asyncmy_driver: AsyncmyDriver) -> None:
     assert verify_result.get_data()[0]["count"] == 0
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_parameter_styles(asyncmy_driver: AsyncmyDriver) -> None:
     """Test different parameter binding styles."""
     driver = asyncmy_driver
@@ -108,7 +107,6 @@ async def test_asyncmy_parameter_styles(asyncmy_driver: AsyncmyDriver) -> None:
     assert select_result.get_data()[1]["value"] == 20
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_execute_many(asyncmy_driver: AsyncmyDriver) -> None:
     """Test execute_many functionality."""
     driver = asyncmy_driver
@@ -126,7 +124,6 @@ async def test_asyncmy_execute_many(asyncmy_driver: AsyncmyDriver) -> None:
     assert select_result.get_data()[0]["value"] == 100
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_execute_script(asyncmy_driver: AsyncmyDriver) -> None:
     """Test script execution with multiple statements."""
     driver = asyncmy_driver
@@ -148,7 +145,6 @@ async def test_asyncmy_execute_script(asyncmy_driver: AsyncmyDriver) -> None:
     assert select_result.get_data()[1]["value"] == 4000
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_data_types(asyncmy_driver: AsyncmyDriver) -> None:
     """Test handling of various MySQL data types."""
     driver = asyncmy_driver
@@ -187,9 +183,60 @@ async def test_asyncmy_data_types(asyncmy_driver: AsyncmyDriver) -> None:
     assert row["int_col"] == 42
     assert abs(row["float_col"] - math.pi) < 0.01
     assert row["bool_col"] == 1
+    assert isinstance(row["json_col"], dict)
+    assert row["json_col"]["key"] == "value"
+
+
+async def test_asyncmy_driver_features_custom_serializers(mysql_service: MySQLService) -> None:
+    """Ensure custom serializer and deserializer driver features are applied."""
+
+    serializer_calls: list[object] = []
+
+    def tracking_serializer(value: object) -> str:
+        serializer_calls.append(value)
+        return to_json(value)
+
+    def tracking_deserializer(value: str | bytes) -> object:
+        decoded = from_json(value)
+        if isinstance(decoded, dict):
+            decoded["extra_marker"] = True
+        return decoded
+
+    config = AsyncmyConfig(
+        pool_config={
+            "host": mysql_service.host,
+            "port": mysql_service.port,
+            "user": mysql_service.user,
+            "password": mysql_service.password,
+            "database": mysql_service.db,
+            "autocommit": True,
+        },
+        driver_features={"json_serializer": tracking_serializer, "json_deserializer": tracking_deserializer},
+    )
+
+    async with config.provide_session() as session:
+        await session.execute_script(
+            """
+            CREATE TABLE IF NOT EXISTS driver_feature_test (
+                id INT AUTO_INCREMENT PRIMARY KEY,
+                payload JSON
+            );
+            TRUNCATE TABLE driver_feature_test;
+            """
+        )
+
+        payload = {"foo": "bar"}
+        await session.execute("INSERT INTO driver_feature_test (payload) VALUES (?)", (payload,))
+
+        assert serializer_calls
+        assert serializer_calls[0] == payload
+
+        select_result = await session.execute("SELECT payload FROM driver_feature_test ORDER BY id DESC LIMIT 1")
+        stored_row = select_result.get_data()[0]
+        assert stored_row["payload"]["foo"] == "bar"
+        assert stored_row["payload"]["extra_marker"] is True
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_transaction_management(asyncmy_driver: AsyncmyDriver) -> None:
     """Test transaction management (begin, commit, rollback)."""
     driver = asyncmy_driver
@@ -209,7 +256,6 @@ async def test_asyncmy_transaction_management(asyncmy_driver: AsyncmyDriver) ->
     assert result.get_data()[0]["count"] == 0
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_null_parameters(asyncmy_driver: AsyncmyDriver) -> None:
     """Test handling of NULL parameters."""
     driver = asyncmy_driver
@@ -223,7 +269,6 @@ async def test_asyncmy_null_parameters(asyncmy_driver: AsyncmyDriver) -> None:
     assert select_result.get_data()[0]["value"] is None
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_error_handling(asyncmy_driver: AsyncmyDriver) -> None:
     """Test error handling and exception wrapping."""
     driver = asyncmy_driver
@@ -237,7 +282,6 @@ async def test_asyncmy_error_handling(asyncmy_driver: AsyncmyDriver) -> None:
         await driver.execute("INSERT INTO test_table (id, name, value) VALUES (?, ?, ?)", (1, "user2", 200))
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_large_result_set(asyncmy_driver: AsyncmyDriver) -> None:
     """Test handling of large result sets."""
     driver = asyncmy_driver
@@ -252,7 +296,6 @@ async def test_asyncmy_large_result_set(asyncmy_driver: AsyncmyDriver) -> None:
     assert result.get_data()[99]["name"] == "user_99"
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_mysql_specific_features(asyncmy_driver: AsyncmyDriver) -> None:
     """Test MySQL-specific features and SQL constructs."""
     driver = asyncmy_driver
@@ -269,7 +312,6 @@ async def test_asyncmy_mysql_specific_features(asyncmy_driver: AsyncmyDriver) ->
     assert select_result.get_data()[0]["value"] == 250
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_complex_queries(asyncmy_driver: AsyncmyDriver) -> None:
     """Test complex SQL queries with JOINs, subqueries, etc."""
     driver = asyncmy_driver
@@ -304,7 +346,6 @@ async def test_asyncmy_complex_queries(asyncmy_driver: AsyncmyDriver) -> None:
     assert row["age"] == 30
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_edge_cases(asyncmy_driver: AsyncmyDriver) -> None:
     """Test edge cases and boundary conditions."""
     driver = asyncmy_driver
@@ -328,7 +369,6 @@ async def test_asyncmy_edge_cases(asyncmy_driver: AsyncmyDriver) -> None:
     assert select_result.get_data()[1]["value"] is None
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_result_metadata(asyncmy_driver: AsyncmyDriver) -> None:
     """Test SQL result metadata and properties."""
     driver = asyncmy_driver
@@ -350,7 +390,6 @@ async def test_asyncmy_result_metadata(asyncmy_driver: AsyncmyDriver) -> None:
     assert len(empty_result.get_data()) == 0
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_sql_object_execution(asyncmy_driver: AsyncmyDriver) -> None:
     """Test execution of SQL objects."""
     driver = asyncmy_driver
@@ -372,7 +411,6 @@ async def test_asyncmy_sql_object_execution(asyncmy_driver: AsyncmyDriver) -> No
     assert select_result.operation_type == "SELECT"
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_for_update_locking(asyncmy_driver: AsyncmyDriver) -> None:
     """Test FOR UPDATE row locking with MySQL."""
     from sqlspec import sql
@@ -399,7 +437,6 @@ async def test_asyncmy_for_update_locking(asyncmy_driver: AsyncmyDriver) -> None
         raise
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_for_update_skip_locked(asyncmy_driver: AsyncmyDriver) -> None:
     """Test FOR UPDATE SKIP LOCKED with MySQL (MySQL 8.0+ feature)."""
     from sqlspec import sql
@@ -425,7 +462,6 @@ async def test_asyncmy_for_update_skip_locked(asyncmy_driver: AsyncmyDriver) ->
         raise
 
 
-@pytest.mark.asyncio
 async def test_asyncmy_for_share_locking(asyncmy_driver: AsyncmyDriver) -> None:
     """Test FOR SHARE row locking with MySQL."""
     from sqlspec import sql
