@@ -3,15 +3,18 @@ from pytest_databases.docker.postgres import PostgresService
 
 from sqlspec.adapters.asyncpg import AsyncpgConfig
 
+pytestmark = pytest.mark.xdist_group("postgres")
+
 
-@pytest.mark.xdist_group("postgres")
 async def test_async_connection(postgres_service: PostgresService) -> None:
     """Test asyncpg connection components."""
     # Test direct connection
     async_config = AsyncpgConfig(
-        dsn=f"postgres://{postgres_service.user}:{postgres_service.password}@{postgres_service.host}:{postgres_service.port}/{postgres_service.database}",
-        min_size=1,
-        max_size=2,
+        pool_config={
+            "dsn": f"postgres://{postgres_service.user}:{postgres_service.password}@{postgres_service.host}:{postgres_service.port}/{postgres_service.database}",
+            "min_size": 1,
+            "max_size": 2,
+        }
     )
 
     conn = await async_config.create_connection()
@@ -25,9 +28,11 @@ async def test_async_connection(postgres_service: PostgresService) -> None:
 
     # Test connection pool
     another_config = AsyncpgConfig(
-        dsn=f"postgres://{postgres_service.user}:{postgres_service.password}@{postgres_service.host}:{postgres_service.port}/{postgres_service.database}",
-        min_size=1,
-        max_size=5,
+        pool_config={
+            "dsn": f"postgres://{postgres_service.user}:{postgres_service.password}@{postgres_service.host}:{postgres_service.port}/{postgres_service.database}",
+            "min_size": 1,
+            "max_size": 5,
+        }
     )
     # Ensure the pool is created before use if not explicitly managed elsewhere
     await another_config.create_pool()
