@@ -5,19 +5,22 @@ from collections.abc import Generator
 import pytest
 
 from sqlspec.adapters.duckdb import DuckDBConfig, DuckDBDriver
-from sqlspec.statement.result import SQLResult
-from sqlspec.statement.sql import SQLConfig
+from sqlspec.core.result import SQLResult
+
+pytestmark = pytest.mark.xdist_group("duckdb")
 
 
 @pytest.fixture
 def duckdb_batch_session() -> "Generator[DuckDBDriver, None, None]":
     """Create a DuckDB session for batch operation testing."""
-    config = DuckDBConfig(database=":memory:", statement_config=SQLConfig())
+    import uuid
+
+    # Use unique database for each test to avoid data contamination
+    config = DuckDBConfig(pool_config={"database": f":memory:{uuid.uuid4().hex}"})
 
     with config.provide_session() as session:
-        # Create test table
         session.execute_script("""
-            CREATE TABLE IF NOT EXISTS test_batch (
+            CREATE TABLE test_batch (
                 id INTEGER PRIMARY KEY,
                 name VARCHAR NOT NULL,
                 value INTEGER DEFAULT 0,
@@ -42,31 +45,28 @@ def test_duckdb_execute_many_basic(duckdb_batch_session: DuckDBDriver) -> None:
     )
 
     assert isinstance(result, SQLResult)
-    # DuckDB should report the number of rows affected
+
     assert result.rows_affected == 5
 
-    # Verify data was inserted
     count_result = duckdb_batch_session.execute("SELECT COUNT(*) as count FROM test_batch")
     assert count_result.data[0]["count"] == 5
 
 
 def test_duckdb_execute_many_update(duckdb_batch_session: DuckDBDriver) -> None:
     """Test execute_many for UPDATE operations with DuckDB."""
-    # First insert some data
+
     duckdb_batch_session.execute_many(
         "INSERT INTO test_batch (id, name, value, category) VALUES (?, ?, ?, ?)",
         [(1, "Update 1", 10, "X"), (2, "Update 2", 20, "Y"), (3, "Update 3", 30, "Z")],
     )
 
-    # Now update with execute_many
-    update_params = [(100, "Update 1"), (200, "Update 2"), (300, "Update 3")]
+    update_parameters = [(100, "Update 1"), (200, "Update 2"), (300, "Update 3")]
 
-    result = duckdb_batch_session.execute_many("UPDATE test_batch SET value = ? WHERE name = ?", update_params)
+    result = duckdb_batch_session.execute_many("UPDATE test_batch SET value = ? WHERE name = ?", update_parameters)
 
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 3
 
-    # Verify updates
     check_result = duckdb_batch_session.execute("SELECT name, value FROM test_batch ORDER BY name")
     assert len(check_result.data) == 3
     assert all(row["value"] in (100, 200, 300) for row in check_result.data)
@@ -81,7 +81,6 @@ def test_duckdb_execute_many_empty(duckdb_batch_session: DuckDBDriver) -> None:
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 0
 
-    # Verify no data was inserted
     count_result = duckdb_batch_session.execute("SELECT COUNT(*) as count FROM test_batch")
     assert count_result.data[0]["count"] == 0
 
@@ -90,9 +89,9 @@ def test_duckdb_execute_many_mixed_types(duckdb_batch_session: DuckDBDriver) ->
     """Test execute_many with mixed parameter types on DuckDB."""
     parameters = [
         (1, "String Item", 123, "CAT1"),
-        (2, "Another Item", 456, None),  # NULL category
+        (2, "Another Item", 456, None),
         (3, "Third Item", 0, "CAT2"),
-        (4, "Float Item", 78.5, "CAT3"),  # DuckDB handles mixed numeric types
+        (4, "Float Item", 78.5, "CAT3"),
     ]
 
     result = duckdb_batch_session.execute_many(
@@ -102,20 +101,18 @@ def test_duckdb_execute_many_mixed_types(duckdb_batch_session: DuckDBDriver) ->
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 4
 
-    # Verify data including NULL
     null_result = duckdb_batch_session.execute("SELECT * FROM test_batch WHERE category IS NULL")
     assert len(null_result.data) == 1
     assert null_result.data[0]["name"] == "Another Item"
 
-    # Verify float value was stored correctly
     float_result = duckdb_batch_session.execute("SELECT * FROM test_batch WHERE name = ?", ("Float Item",))
     assert len(float_result.data) == 1
-    assert float_result.data[0]["value"] == 78  # DuckDB converts float to int for INTEGER column
+    assert float_result.data[0]["value"] == 78
 
 
 def test_duckdb_execute_many_delete(duckdb_batch_session: DuckDBDriver) -> None:
     """Test execute_many for DELETE operations with DuckDB."""
-    # First insert test data
+
     duckdb_batch_session.execute_many(
         "INSERT INTO test_batch (id, name, value, category) VALUES (?, ?, ?, ?)",
         [
@@ -127,19 +124,16 @@ def test_duckdb_execute_many_delete(duckdb_batch_session: DuckDBDriver) -> None:
         ],
     )
 
-    # Delete specific items by name
-    delete_params = [("Delete 1",), ("Delete 2",), ("Delete 4",)]
+    delete_parameters = [("Delete 1",), ("Delete 2",), ("Delete 4",)]
 
-    result = duckdb_batch_session.execute_many("DELETE FROM test_batch WHERE name = ?", delete_params)
+    result = duckdb_batch_session.execute_many("DELETE FROM test_batch WHERE name = ?", delete_parameters)
 
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 3
 
-    # Verify remaining data
     remaining_result = duckdb_batch_session.execute("SELECT COUNT(*) as count FROM test_batch")
     assert remaining_result.data[0]["count"] == 2
 
-    # Verify specific remaining items
     names_result = duckdb_batch_session.execute("SELECT name FROM test_batch ORDER BY name")
     remaining_names = [row["name"] for row in names_result.data]
     assert remaining_names == ["Delete 3", "Keep 1"]
@@ -147,7 +141,7 @@ def test_duckdb_execute_many_delete(duckdb_batch_session: DuckDBDriver) -> None:
 
 def test_duckdb_execute_many_large_batch(duckdb_batch_session: DuckDBDriver) -> None:
     """Test execute_many with large batch size on DuckDB."""
-    # Create a large batch of parameters
+
     large_batch = [(i, f"Item {i}", i * 10, f"CAT{i % 3}") for i in range(1000)]
 
     result = duckdb_batch_session.execute_many(
@@ -157,48 +151,44 @@ def test_duckdb_execute_many_large_batch(duckdb_batch_session: DuckDBDriver) ->
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 1000
 
-    # Verify count
     count_result = duckdb_batch_session.execute("SELECT COUNT(*) as count FROM test_batch")
     assert count_result.data[0]["count"] == 1000
 
-    # Verify some specific values
     sample_result = duckdb_batch_session.execute(
         "SELECT * FROM test_batch WHERE name IN (?, ?, ?) ORDER BY value", ("Item 100", "Item 500", "Item 999")
     )
     assert len(sample_result.data) == 3
-    assert sample_result.data[0]["value"] == 1000  # Item 100
-    assert sample_result.data[1]["value"] == 5000  # Item 500
-    assert sample_result.data[2]["value"] == 9990  # Item 999
+    assert sample_result.data[0]["value"] == 1000
+    assert sample_result.data[1]["value"] == 5000
+    assert sample_result.data[2]["value"] == 9990
 
 
 def test_duckdb_execute_many_with_sql_object(duckdb_batch_session: DuckDBDriver) -> None:
     """Test execute_many with SQL object on DuckDB."""
-    from sqlspec.statement.sql import SQL
+    from sqlspec.core.statement import SQL
 
     parameters = [(10, "SQL Obj 1", 111, "SOB"), (20, "SQL Obj 2", 222, "SOB"), (30, "SQL Obj 3", 333, "SOB")]
 
-    sql_obj = SQL("INSERT INTO test_batch (id, name, value, category) VALUES (?, ?, ?, ?)").as_many(parameters)
+    sql_obj = SQL("INSERT INTO test_batch (id, name, value, category) VALUES (?, ?, ?, ?)", parameters, is_many=True)
 
     result = duckdb_batch_session.execute(sql_obj)
 
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 3
 
-    # Verify data
     check_result = duckdb_batch_session.execute("SELECT COUNT(*) as count FROM test_batch WHERE category = ?", ("SOB"))
     assert check_result.data[0]["count"] == 3
 
 
 def test_duckdb_execute_many_with_analytics(duckdb_batch_session: DuckDBDriver) -> None:
     """Test execute_many with DuckDB analytics features."""
-    # Insert data for analytics
+
     analytics_data = [(i, f"Analytics {i}", i * 10, f"ANAL{i % 2}") for i in range(1, 11)]
 
     duckdb_batch_session.execute_many(
         "INSERT INTO test_batch (id, name, value, category) VALUES (?, ?, ?, ?)", analytics_data
     )
 
-    # Test analytics query after batch insert
     result = duckdb_batch_session.execute("""
         SELECT
             category,
@@ -212,19 +202,18 @@ def test_duckdb_execute_many_with_analytics(duckdb_batch_session: DuckDBDriver)
         ORDER BY category
     """)
 
-    assert len(result.data) == 2  # ANAL0 and ANAL1
+    assert len(result.data) == 2
 
-    # Verify analytics results
     anal0_data = next(row for row in result.data if row["category"] == "ANAL0")
     anal1_data = next(row for row in result.data if row["category"] == "ANAL1")
 
-    assert anal0_data["count"] == 5  # Even numbers: 2, 4, 6, 8, 10
-    assert anal1_data["count"] == 5  # Odd numbers: 1, 3, 5, 7, 9
+    assert anal0_data["count"] == 5
+    assert anal1_data["count"] == 5
 
 
 def test_duckdb_execute_many_with_arrays(duckdb_batch_session: DuckDBDriver) -> None:
     """Test execute_many with DuckDB array operations."""
-    # Create table with array support
+
     duckdb_batch_session.execute_script("""
         CREATE TABLE IF NOT EXISTS test_arrays (
             id INTEGER PRIMARY KEY,
@@ -234,7 +223,6 @@ def test_duckdb_execute_many_with_arrays(duckdb_batch_session: DuckDBDriver) ->
         )
     """)
 
-    # Note: DuckDB array syntax may differ, using basic types for compatibility
     parameters = [
         (1, "Array 1", [10, 20, 30], ["tag1", "tag2"]),
         (2, "Array 2", [40, 50], ["tag3"]),
@@ -249,18 +237,16 @@ def test_duckdb_execute_many_with_arrays(duckdb_batch_session: DuckDBDriver) ->
         assert isinstance(result, SQLResult)
         assert result.rows_affected == 3
 
-        # Verify array data
         check_result = duckdb_batch_session.execute(
             "SELECT name, len(numbers) as num_count, len(tags) as tag_count FROM test_arrays ORDER BY name"
         )
         assert len(check_result.data) == 3
 
     except Exception:
-        # If DuckDB array syntax is different, test with simpler data
-        simple_params = [(1, "Simple 1", 10, "tag1"), (2, "Simple 2", 20, "tag2"), (3, "Simple 3", 30, "tag3")]
+        simple_parameters = [(1, "Simple 1", 10, "tag1"), (2, "Simple 2", 20, "tag2"), (3, "Simple 3", 30, "tag3")]
 
         duckdb_batch_session.execute_many(
-            "INSERT INTO test_batch (id, name, value, category) VALUES (?, ?, ?, ?)", simple_params
+            "INSERT INTO test_batch (id, name, value, category) VALUES (?, ?, ?, ?)", simple_parameters
         )
 
         check_result = duckdb_batch_session.execute("SELECT COUNT(*) as count FROM test_batch")
@@ -269,7 +255,7 @@ def test_duckdb_execute_many_with_arrays(duckdb_batch_session: DuckDBDriver) ->
 
 def test_duckdb_execute_many_with_time_series(duckdb_batch_session: DuckDBDriver) -> None:
     """Test execute_many with time series data on DuckDB."""
-    # Create time series table
+
     duckdb_batch_session.execute_script("""
         CREATE TABLE IF NOT EXISTS test_timeseries (
             id INTEGER PRIMARY KEY,
@@ -279,14 +265,10 @@ def test_duckdb_execute_many_with_time_series(duckdb_batch_session: DuckDBDriver
         )
     """)
 
-    # Generate time series data
     from datetime import datetime, timedelta
 
     base_time = datetime(2024, 1, 1)
-    time_series_data = [
-        (i, base_time + timedelta(hours=i), f"metric_{i % 3}", float(i * 10.5))
-        for i in range(1, 25)  # 24 hours of data
-    ]
+    time_series_data = [(i, base_time + timedelta(hours=i), f"metric_{i % 3}", float(i * 10.5)) for i in range(1, 25)]
 
     result = duckdb_batch_session.execute_many(
         "INSERT INTO test_timeseries (id, timestamp, metric_name, metric_value) VALUES (?, ?, ?, ?)", time_series_data
@@ -295,7 +277,6 @@ def test_duckdb_execute_many_with_time_series(duckdb_batch_session: DuckDBDriver
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 24
 
-    # Test time series analytics
     analytics_result = duckdb_batch_session.execute("""
         SELECT
             metric_name,
@@ -308,8 +289,7 @@ def test_duckdb_execute_many_with_time_series(duckdb_batch_session: DuckDBDriver
         ORDER BY metric_name
     """)
 
-    assert len(analytics_result.data) == 3  # metric_0, metric_1, metric_2
+    assert len(analytics_result.data) == 3
 
-    # Each metric should have 8 data points (24/3)
     for row in analytics_result.data:
         assert row["data_points"] == 8
