@@ -1,72 +1,44 @@
 """Integration tests for SQLite driver implementation."""
 
 import math
-import tempfile
-from collections.abc import Generator
 from typing import Any, Literal
 
-import pyarrow.parquet as pq
 import pytest
 
-from sqlspec.adapters.sqlite import SqliteConfig, SqliteDriver
-from sqlspec.statement.result import ArrowResult, SQLResult
-from sqlspec.statement.sql import SQL
+from sqlspec.adapters.sqlite import SqliteDriver
+from sqlspec.core.result import SQLResult
 
+pytestmark = pytest.mark.xdist_group("sqlite")
 ParamStyle = Literal["tuple_binds", "dict_binds", "named_binds"]
 
 
-@pytest.fixture
-def sqlite_session() -> Generator[SqliteDriver, None, None]:
-    """Create a SQLite session with test table."""
-    config = SqliteConfig(database=":memory:")
-
-    with config.provide_session() as session:
-        # Create test table
-        session.execute_script("""
-            CREATE TABLE IF NOT EXISTS test_table (
-                id INTEGER PRIMARY KEY AUTOINCREMENT,
-                name TEXT NOT NULL,
-                value INTEGER DEFAULT 0,
-                created_at DATETIME DEFAULT CURRENT_TIMESTAMP
-            )
-        """)
-        yield session
-        # Cleanup is automatic with in-memory database
-
-
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_basic_crud(sqlite_session: SqliteDriver) -> None:
     """Test basic CRUD operations."""
-    # INSERT
+
     insert_result = sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("test_name", 42))
     assert isinstance(insert_result, SQLResult)
     assert insert_result.rows_affected == 1
 
-    # SELECT
-    select_result = sqlite_session.execute("SELECT name, value FROM test_table WHERE name = ?", ("test_name"))
+    select_result = sqlite_session.execute("SELECT name, value FROM test_table WHERE name = ?", ("test_name",))
     assert isinstance(select_result, SQLResult)
     assert select_result.data is not None
     assert len(select_result.data) == 1
     assert select_result.data[0]["name"] == "test_name"
     assert select_result.data[0]["value"] == 42
 
-    # UPDATE
     update_result = sqlite_session.execute("UPDATE test_table SET value = ? WHERE name = ?", (100, "test_name"))
     assert isinstance(update_result, SQLResult)
     assert update_result.rows_affected == 1
 
-    # Verify UPDATE
-    verify_result = sqlite_session.execute("SELECT value FROM test_table WHERE name = ?", ("test_name"))
+    verify_result = sqlite_session.execute("SELECT value FROM test_table WHERE name = ?", ("test_name",))
     assert isinstance(verify_result, SQLResult)
     assert verify_result.data is not None
     assert verify_result.data[0]["value"] == 100
 
-    # DELETE
-    delete_result = sqlite_session.execute("DELETE FROM test_table WHERE name = ?", ("test_name"))
+    delete_result = sqlite_session.execute("DELETE FROM test_table WHERE name = ?", ("test_name",))
     assert isinstance(delete_result, SQLResult)
     assert delete_result.rows_affected == 1
 
-    # Verify DELETE
     empty_result = sqlite_session.execute("SELECT COUNT(*) as count FROM test_table")
     assert isinstance(empty_result, SQLResult)
     assert empty_result.data is not None
@@ -74,47 +46,49 @@ def test_sqlite_basic_crud(sqlite_session: SqliteDriver) -> None:
 
 
 @pytest.mark.parametrize(
-    ("params", "style"),
+    ("parameters", "style"),
     [
         pytest.param(("test_value"), "tuple_binds", id="tuple_binds"),
         pytest.param({"name": "test_value"}, "dict_binds", id="dict_binds"),
     ],
 )
-@pytest.mark.xdist_group("sqlite")
-def test_sqlite_parameter_styles(sqlite_session: SqliteDriver, params: Any, style: ParamStyle) -> None:
+def test_sqlite_parameter_styles(sqlite_session: SqliteDriver, parameters: Any, style: ParamStyle) -> None:
     """Test different parameter binding styles."""
-    # Insert test data
-    sqlite_session.execute("INSERT INTO test_table (name) VALUES (?)", ("test_value"))
 
-    # Test parameter style
+    sqlite_session.execute("DELETE FROM test_table")
+    sqlite_session.commit()
+
+    sqlite_session.execute("INSERT INTO test_table (name) VALUES (?)", ("test_value",))
+
     if style == "tuple_binds":
         sql = "SELECT name FROM test_table WHERE name = ?"
-    else:  # dict_binds
+    else:
         sql = "SELECT name FROM test_table WHERE name = :name"
 
-    result = sqlite_session.execute(sql, params)
+    result = sqlite_session.execute(sql, parameters)
     assert isinstance(result, SQLResult)
     assert result.data is not None
     assert len(result.data) == 1
     assert result.data[0]["name"] == "test_value"
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_execute_many(sqlite_session: SqliteDriver) -> None:
     """Test execute_many functionality."""
-    params_list = [("name1", 1), ("name2", 2), ("name3", 3)]
 
-    result = sqlite_session.execute_many("INSERT INTO test_table (name, value) VALUES (?, ?)", params_list)
+    sqlite_session.execute("DELETE FROM test_table")
+    sqlite_session.commit()
+
+    parameters_list = [("name1", 1), ("name2", 2), ("name3", 3)]
+
+    result = sqlite_session.execute_many("INSERT INTO test_table (name, value) VALUES (?, ?)", parameters_list)
     assert isinstance(result, SQLResult)
-    assert result.rows_affected == len(params_list)
+    assert result.rows_affected == len(parameters_list)
 
-    # Verify all records were inserted
     select_result = sqlite_session.execute("SELECT COUNT(*) as count FROM test_table")
     assert isinstance(select_result, SQLResult)
     assert select_result.data is not None
-    assert select_result.data[0]["count"] == len(params_list)
+    assert select_result.data[0]["count"] == len(parameters_list)
 
-    # Verify data integrity
     ordered_result = sqlite_session.execute("SELECT name, value FROM test_table ORDER BY name")
     assert isinstance(ordered_result, SQLResult)
     assert ordered_result.data is not None
@@ -123,7 +97,6 @@ def test_sqlite_execute_many(sqlite_session: SqliteDriver) -> None:
     assert ordered_result.data[0]["value"] == 1
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_execute_script(sqlite_session: SqliteDriver) -> None:
     """Test execute_script functionality."""
     script = """
@@ -136,17 +109,13 @@ def test_sqlite_execute_script(sqlite_session: SqliteDriver) -> None:
         result = sqlite_session.execute_script(script)
     except Exception as e:
         pytest.fail(f"execute_script raised an unexpected exception: {e}")
-    # Script execution now returns SQLResult object
+
     assert isinstance(result, SQLResult)
     assert result.operation_type == "SCRIPT"
 
-    # Explicitly check for errors from the script execution itself
     if hasattr(result, "errors") and result.errors:
         pytest.fail(f"Script execution reported errors: {result.errors}")
-    if hasattr(result, "has_errors") and callable(result.has_errors) and result.has_errors():
-        pytest.fail(f"Script execution reported errors (via has_errors): {result.get_errors()}")
 
-    # Verify script effects
     select_result = sqlite_session.execute(
         "SELECT name, value FROM test_table WHERE name LIKE 'script_test%' ORDER BY name"
     )
@@ -159,56 +128,48 @@ def test_sqlite_execute_script(sqlite_session: SqliteDriver) -> None:
     assert select_result.data[1]["value"] == 888
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_result_methods(sqlite_session: SqliteDriver) -> None:
     """Test SelectResult and ExecuteResult methods."""
-    # Insert test data
+
+    sqlite_session.execute("DELETE FROM test_table")
+    sqlite_session.commit()
+
     sqlite_session.execute_many(
         "INSERT INTO test_table (name, value) VALUES (?, ?)", [("result1", 10), ("result2", 20), ("result3", 30)]
     )
 
-    # Test SelectResult methods
     result = sqlite_session.execute("SELECT * FROM test_table ORDER BY name")
     assert isinstance(result, SQLResult)
 
-    # Test get_first()
     first_row = result.get_first()
     assert first_row is not None
     assert first_row["name"] == "result1"
 
-    # Test get_count()
     assert result.get_count() == 3
 
-    # Test is_empty()
     assert not result.is_empty()
 
-    # Test empty result
-    empty_result = sqlite_session.execute("SELECT * FROM test_table WHERE name = ?", ("nonexistent"))
+    empty_result = sqlite_session.execute("SELECT * FROM test_table WHERE name = ?", ("nonexistent",))
     assert isinstance(empty_result, SQLResult)
     assert empty_result.is_empty()
     assert empty_result.get_first() is None
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_error_handling(sqlite_session: SqliteDriver) -> None:
     """Test error handling and exception propagation."""
-    # Test invalid SQL
-    with pytest.raises(Exception):  # sqlite3.OperationalError
+
+    with pytest.raises(Exception):
         sqlite_session.execute("INVALID SQL STATEMENT")
 
-    # Test constraint violation
     sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("unique_test", 1))
 
-    # Try to insert duplicate with same ID (should fail if we had unique constraint)
-    # For now, just test invalid column reference
-    with pytest.raises(Exception):  # sqlite3.OperationalError
+    with pytest.raises(Exception):
         sqlite_session.execute("SELECT nonexistent_column FROM test_table")
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_data_types(sqlite_session: SqliteDriver) -> None:
     """Test SQLite data type handling."""
-    # Create table with various data types
+
     sqlite_session.execute_script("""
         CREATE TABLE data_types_test (
             id INTEGER PRIMARY KEY,
@@ -220,7 +181,6 @@ def test_sqlite_data_types(sqlite_session: SqliteDriver) -> None:
         )
     """)
 
-    # Insert data with various types
     test_data = ("text_value", 42, math.pi, b"binary_data", None)
 
     insert_result = sqlite_session.execute(
@@ -230,7 +190,6 @@ def test_sqlite_data_types(sqlite_session: SqliteDriver) -> None:
     assert isinstance(insert_result, SQLResult)
     assert insert_result.rows_affected == 1
 
-    # Retrieve and verify data
     select_result = sqlite_session.execute(
         "SELECT text_col, integer_col, real_col, blob_col, null_col FROM data_types_test"
     )
@@ -246,28 +205,27 @@ def test_sqlite_data_types(sqlite_session: SqliteDriver) -> None:
     assert row["null_col"] is None
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_transactions(sqlite_session: SqliteDriver) -> None:
     """Test transaction behavior."""
-    # SQLite auto-commit mode test
+
     sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("transaction_test", 100))
 
-    # Verify data is committed
-    result = sqlite_session.execute("SELECT COUNT(*) as count FROM test_table WHERE name = ?", ("transaction_test"))
+    result = sqlite_session.execute("SELECT COUNT(*) as count FROM test_table WHERE name = ?", ("transaction_test",))
     assert isinstance(result, SQLResult)
     assert result.data is not None
     assert result.data[0]["count"] == 1
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_complex_queries(sqlite_session: SqliteDriver) -> None:
     """Test complex SQL queries."""
-    # Insert test data
+
+    sqlite_session.execute("DELETE FROM test_table")
+    sqlite_session.commit()
+
     test_data = [("Alice", 25), ("Bob", 30), ("Charlie", 35), ("Diana", 28)]
 
     sqlite_session.execute_many("INSERT INTO test_table (name, value) VALUES (?, ?)", test_data)
 
-    # Test JOIN (self-join)
     join_result = sqlite_session.execute("""
         SELECT t1.name as name1, t2.name as name2, t1.value as value1, t2.value as value2
         FROM test_table t1
@@ -280,7 +238,6 @@ def test_sqlite_complex_queries(sqlite_session: SqliteDriver) -> None:
     assert join_result.data is not None
     assert len(join_result.data) == 3
 
-    # Test aggregation
     agg_result = sqlite_session.execute("""
         SELECT
             COUNT(*) as total_count,
@@ -296,7 +253,6 @@ def test_sqlite_complex_queries(sqlite_session: SqliteDriver) -> None:
     assert agg_result.data[0]["min_value"] == 25
     assert agg_result.data[0]["max_value"] == 35
 
-    # Test subquery
     subquery_result = sqlite_session.execute("""
         SELECT name, value
         FROM test_table
@@ -305,15 +261,14 @@ def test_sqlite_complex_queries(sqlite_session: SqliteDriver) -> None:
     """)
     assert isinstance(subquery_result, SQLResult)
     assert subquery_result.data is not None
-    assert len(subquery_result.data) == 2  # Bob and Charlie
+    assert len(subquery_result.data) == 2
     assert subquery_result.data[0]["name"] == "Bob"
     assert subquery_result.data[1]["name"] == "Charlie"
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_schema_operations(sqlite_session: SqliteDriver) -> None:
     """Test schema operations (DDL)."""
-    # Create a new table
+
     create_result = sqlite_session.execute_script("""
         CREATE TABLE schema_test (
             id INTEGER PRIMARY KEY,
@@ -324,39 +279,33 @@ def test_sqlite_schema_operations(sqlite_session: SqliteDriver) -> None:
     assert isinstance(create_result, SQLResult)
     assert create_result.operation_type == "SCRIPT"
 
-    # Insert data into new table
-    insert_result = sqlite_session.execute("INSERT INTO schema_test (description) VALUES (?)", ("test description"))
+    insert_result = sqlite_session.execute("INSERT INTO schema_test (description) VALUES (?)", ("test_description",))
     assert isinstance(insert_result, SQLResult)
     assert insert_result.rows_affected == 1
 
-    # Verify table structure
     pragma_result = sqlite_session.execute("PRAGMA table_info(schema_test)")
     assert isinstance(pragma_result, SQLResult)
     assert pragma_result.data is not None
-    assert len(pragma_result.data) == 3  # id, description, created_at
+    assert len(pragma_result.get_data()) == 3
 
-    # Drop table
     drop_result = sqlite_session.execute_script("DROP TABLE schema_test")
     assert isinstance(drop_result, SQLResult)
     assert drop_result.operation_type == "SCRIPT"
 
 
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_column_names_and_metadata(sqlite_session: SqliteDriver) -> None:
     """Test column names and result metadata."""
-    # Insert test data
+
     sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("metadata_test", 123))
 
-    # Test column names
     result = sqlite_session.execute(
-        "SELECT id, name, value, created_at FROM test_table WHERE name = ?", ("metadata_test")
+        "SELECT id, name, value, created_at FROM test_table WHERE name = ?", ("metadata_test",)
     )
     assert isinstance(result, SQLResult)
     assert result.column_names == ["id", "name", "value", "created_at"]
     assert result.data is not None
     assert len(result.data) == 1
 
-    # Test that we can access data by column name
     row = result.data[0]
     assert row["name"] == "metadata_test"
     assert row["value"] == 123
@@ -364,53 +313,20 @@ def test_sqlite_column_names_and_metadata(sqlite_session: SqliteDriver) -> None:
     assert row["created_at"] is not None
 
 
-@pytest.mark.xdist_group("sqlite")
-def test_sqlite_with_schema_type(sqlite_session: SqliteDriver) -> None:
-    """Test SQLite driver with schema type conversion."""
-    from dataclasses import dataclass
-    from typing import Optional
-
-    @dataclass
-    class TestRecord:
-        id: Optional[int]
-        name: str
-        value: int
-
-    # Insert test data
-    sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("schema_test", 456))
-
-    # Query with schema type
-    result = sqlite_session.execute(
-        "SELECT id, name, value FROM test_table WHERE name = ?", ("schema_test"), schema_type=TestRecord
-    )
-
-    assert isinstance(result, SQLResult)
-    assert result.data is not None
-    assert len(result.data) == 1
-
-    # The data should be converted to the schema type by the ResultConverter
-    # The exact behavior depends on the ResultConverter implementation
-    assert result.column_names == ["id", "name", "value"]
-
-
-@pytest.mark.xdist_group("sqlite")
 def test_sqlite_performance_bulk_operations(sqlite_session: SqliteDriver) -> None:
     """Test performance with bulk operations."""
-    # Generate bulk data
+
     bulk_data = [(f"bulk_user_{i}", i * 10) for i in range(100)]
 
-    # Bulk insert
     result = sqlite_session.execute_many("INSERT INTO test_table (name, value) VALUES (?, ?)", bulk_data)
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 100
 
-    # Bulk select
     select_result = sqlite_session.execute("SELECT COUNT(*) as count FROM test_table WHERE name LIKE 'bulk_user_%'")
     assert isinstance(select_result, SQLResult)
     assert select_result.data is not None
     assert select_result.data[0]["count"] == 100
 
-    # Test pagination-like query
     page_result = sqlite_session.execute(
         "SELECT name, value FROM test_table WHERE name LIKE 'bulk_user_%' ORDER BY value LIMIT 10 OFFSET 20"
     )
@@ -420,40 +336,6 @@ def test_sqlite_performance_bulk_operations(sqlite_session: SqliteDriver) -> Non
     assert page_result.data[0]["name"] == "bulk_user_20"
 
 
-@pytest.mark.xdist_group("sqlite")
-def test_sqlite_fetch_arrow_table(sqlite_session: SqliteDriver) -> None:
-    """Integration test: fetch_arrow_table returns pyarrow.Table directly."""
-    sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("arrow1", 111))
-    sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("arrow2", 222))
-    # fetch_arrow_table expects a SQL string, not a SQL object
-    result = sqlite_session.fetch_arrow_table("SELECT name, value FROM test_table ORDER BY name")
-    assert isinstance(result, ArrowResult)
-    assert result.num_rows == 2
-    assert result.column_names == ["name", "value"]
-    assert result.data is not None
-    assert result.data.column("name").to_pylist() == ["arrow1", "arrow2"]
-    assert result.data.column("value").to_pylist() == [111, 222]
-
-
-@pytest.mark.xdist_group("sqlite")
-def test_sqlite_to_parquet(sqlite_session: SqliteDriver) -> None:
-    """Integration test: to_parquet writes correct data to a Parquet file."""
-    sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("pq1", 10))
-    sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("pq2", 20))
-    SQL("SELECT name, value FROM test_table ORDER BY name")
-    with tempfile.NamedTemporaryFile(suffix=".parquet") as tmpfile:
-        # export_to_storage expects query string and destination_uri
-        sqlite_session.export_to_storage(
-            "SELECT name, value FROM test_table ORDER BY name", destination_uri=tmpfile.name
-        )
-        table = pq.read_table(tmpfile.name)
-        assert table.num_rows == 2
-        assert table.column_names == ["name", "value"]
-        assert table.column("name").to_pylist() == ["pq1", "pq2"]
-        assert table.column("value").to_pylist() == [10, 20]
-
-
-@pytest.mark.xdist_group("sqlite")
 def test_asset_maintenance_alert_complex_query(sqlite_session: SqliteDriver) -> None:
     """Test complex CTE query with INSERT, ON CONFLICT, RETURNING, and LEFT JOIN.
 
@@ -465,7 +347,7 @@ def test_asset_maintenance_alert_complex_query(sqlite_session: SqliteDriver) ->
     - LEFT JOIN with to_jsonb function
     - Named parameters (:date_start, :date_end)
     """
-    # Create required tables
+
     sqlite_session.execute_script("""
         CREATE TABLE alert_definition (
             id INTEGER PRIMARY KEY,
@@ -498,10 +380,8 @@ def test_asset_maintenance_alert_complex_query(sqlite_session: SqliteDriver) ->
         );
     """)
 
-    # Insert test data
     sqlite_session.execute("INSERT INTO alert_definition (id, name) VALUES (?, ?)", (1, "maintenances_today"))
 
-    # Insert users
     sqlite_session.execute_many(
         "INSERT INTO users (id, name, email) VALUES (?, ?, ?)",
         [
@@ -511,25 +391,18 @@ def test_asset_maintenance_alert_complex_query(sqlite_session: SqliteDriver) ->
         ],
     )
 
-    # Insert asset maintenance records
     sqlite_session.execute_many(
         "INSERT INTO asset_maintenance (id, responsible_id, planned_date_start, cancelled) VALUES (?, ?, ?, ?)",
         [
-            (1, 1, "2024-01-15", False),  # Within date range
-            (2, 2, "2024-01-16", False),  # Within date range
-            (3, 3, "2024-01-17", False),  # Within date range
-            (4, 1, "2024-01-18", True),  # Cancelled - should be excluded
-            (5, 2, "2024-01-10", False),  # Outside date range
-            (6, 3, "2024-01-20", False),  # Outside date range
+            (1, 1, "2024-01-15", False),
+            (2, 2, "2024-01-16", False),
+            (3, 3, "2024-01-17", False),
+            (4, 1, "2024-01-18", True),
+            (5, 2, "2024-01-10", False),
+            (6, 3, "2024-01-20", False),
         ],
     )
 
-    # Test the complex query
-    # Note: SQLite doesn't have to_jsonb, so we'll adapt the query
-    # Also, SQLite doesn't support INSERT...RETURNING directly in CTEs the same way as PostgreSQL
-    # So we'll split this into two operations for SQLite compatibility
-
-    # First, perform the INSERT with ON CONFLICT
     insert_result = sqlite_session.execute(
         """
         INSERT INTO alert_users (user_id, asset_maintenance_id, alert_definition_id)
@@ -543,10 +416,11 @@ def test_asset_maintenance_alert_complex_query(sqlite_session: SqliteDriver) ->
         {"date_start": "2024-01-15", "date_end": "2024-01-17"},
     )
 
+    sqlite_session.connection.commit()
+
     assert isinstance(insert_result, SQLResult)
-    assert insert_result.rows_affected == 3  # Should insert 3 records
+    assert insert_result.rows_affected == 3
 
-    # Then, query the inserted data with the LEFT JOIN pattern
     select_result = sqlite_session.execute("""
         SELECT
             au.*,
@@ -563,7 +437,6 @@ def test_asset_maintenance_alert_complex_query(sqlite_session: SqliteDriver) ->
     assert select_result.data is not None
     assert len(select_result.data) == 3
 
-    # Verify the data structure
     for row in select_result.data:
         assert row["user_id"] in [1, 2, 3]
         assert row["asset_maintenance_id"] in [1, 2, 3]
@@ -571,7 +444,6 @@ def test_asset_maintenance_alert_complex_query(sqlite_session: SqliteDriver) ->
         assert row["user_name"] in ["John Doe", "Jane Smith", "Bob Wilson"]
         assert "@example.com" in row["user_email"]
 
-    # Test idempotency - running the same INSERT again should not add duplicates
     insert_result2 = sqlite_session.execute(
         """
         INSERT INTO alert_users (user_id, asset_maintenance_id, alert_definition_id)
@@ -585,9 +457,75 @@ def test_asset_maintenance_alert_complex_query(sqlite_session: SqliteDriver) ->
         {"date_start": "2024-01-15", "date_end": "2024-01-17"},
     )
 
-    assert insert_result2.rows_affected == 0  # No new rows should be inserted
+    assert insert_result2.rows_affected == 0
 
-    # Verify total count is still 3
     count_result = sqlite_session.execute("SELECT COUNT(*) as count FROM alert_users")
     assert count_result.data is not None
     assert count_result.data[0]["count"] == 3
+
+
+def test_sqlite_for_update_generates_sql_but_may_not_work(sqlite_session: SqliteDriver) -> None:
+    """Test that FOR UPDATE generates SQL for SQLite but note it doesn't provide row-level locking."""
+    from sqlspec import sql
+
+    # Insert test data
+    sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("sqlite_test", 100))
+
+    # SQLite will generate FOR UPDATE SQL but it doesn't provide row-level locking like PostgreSQL/MySQL
+    # The SQL should be generated without errors, but SQLite ignores the FOR UPDATE clause
+    query = sql.select("*").from_("test_table").where_eq("name", "sqlite_test").for_update()
+
+    # Should generate SQL without throwing an error
+    stmt = query.build()
+    # SQLite doesn't support FOR UPDATE, so SQLGlot strips it out (expected behavior)
+    assert "FOR UPDATE" not in stmt.sql
+    assert "SELECT" in stmt.sql  # But the rest of the query works
+
+    # Should execute without error (SQLite just ignores the FOR UPDATE)
+    result = sqlite_session.execute(query)
+    assert result is not None
+    assert len(result.data) == 1
+    assert result.data[0]["name"] == "sqlite_test"
+
+
+def test_sqlite_for_share_generates_sql_but_may_not_work(sqlite_session: SqliteDriver) -> None:
+    """Test that FOR SHARE generates SQL for SQLite but note it doesn't provide row-level locking."""
+    from sqlspec import sql
+
+    # Insert test data
+    sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("sqlite_share", 200))
+
+    # SQLite will generate FOR SHARE SQL but it doesn't provide row-level locking
+    query = sql.select("*").from_("test_table").where_eq("name", "sqlite_share").for_share()
+
+    # Should generate SQL without throwing an error
+    stmt = query.build()
+    # SQLite doesn't support FOR SHARE, so SQLGlot strips it out (expected behavior)
+    assert "FOR SHARE" not in stmt.sql
+    assert "SELECT" in stmt.sql  # But the rest of the query works
+
+    # Should execute without error (SQLite just ignores the FOR SHARE)
+    result = sqlite_session.execute(query)
+    assert result is not None
+    assert len(result.data) == 1
+    assert result.data[0]["name"] == "sqlite_share"
+
+
+def test_sqlite_for_update_skip_locked_generates_sql(sqlite_session: SqliteDriver) -> None:
+    """Test that FOR UPDATE SKIP LOCKED generates SQL for SQLite."""
+    from sqlspec import sql
+
+    # Insert test data
+    sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("sqlite_skip", 300))
+
+    # Should generate SQL even though SQLite doesn't support the functionality
+    query = sql.select("*").from_("test_table").where_eq("name", "sqlite_skip").for_update(skip_locked=True)
+
+    stmt = query.build()
+    # The exact SQL generated may vary based on dialect support
+    assert stmt.sql is not None
+
+    # Should execute (SQLite will ignore unsupported clauses)
+    result = sqlite_session.execute(query)
+    assert result is not None
+    assert len(result.data) == 1
