@@ -46,7 +46,7 @@ class MockSyncConnection:
         self.cursor_results: list[dict[str, Any]] = []
         self.execute_count = 0
         self.execute_many_count = 0
-        self.last_sql: Optional[str] = None
+        self.last_sql: str | None = None
         self.last_parameters: Any = None
 
     def cursor(self) -> "MockSyncCursor":
@@ -82,7 +82,7 @@ class MockAsyncConnection:
         self.cursor_results: list[dict[str, Any]] = []
         self.execute_count = 0
         self.execute_many_count = 0
-        self.last_sql: Optional[str] = None
+        self.last_sql: str | None = None
         self.last_parameters: Any = None
 
     async def cursor(self) -> "MockAsyncCursor":
@@ -114,7 +114,7 @@ class MockSyncCursor:
     def __init__(self, connection: MockSyncConnection) -> None:
         self.connection = connection
         self.rowcount = 0
-        self.description: Optional[list[tuple[str, ...]]] = None
+        self.description: list[tuple[str, ...]] | None = None
         self.fetchall_result: list[tuple[Any, ...]] = []
         self.closed = False
 
@@ -156,7 +156,7 @@ class MockAsyncCursor:
     def __init__(self, connection: MockAsyncConnection) -> None:
         self.connection = connection
         self.rowcount = 0
-        self.description: Optional[list[tuple[str, ...]]] = None
+        self.description: list[tuple[str, ...]] | None = None
         self.fetchall_result: list[tuple[Any, ...]] = []
         self.closed = False
 
@@ -203,7 +203,7 @@ class MockAsyncCursor:
 class MockSyncDataDictionary(SyncDataDictionaryBase):
     """Mock sync data dictionary for testing."""
 
-    def get_version(self, driver: SyncDriverAdapterBase) -> "Optional[VersionInfo]":
+    def get_version(self, driver: SyncDriverAdapterBase) -> "VersionInfo | None":
         """Return mock version info."""
         return VersionInfo(3, 42, 0)
 
@@ -223,7 +223,7 @@ class MockSyncDataDictionary(SyncDataDictionaryBase):
 class MockAsyncDataDictionary(AsyncDataDictionaryBase):
     """Mock async data dictionary for testing."""
 
-    async def get_version(self, driver: AsyncDriverAdapterBase) -> "Optional[VersionInfo]":
+    async def get_version(self, driver: AsyncDriverAdapterBase) -> "VersionInfo | None":
         """Return mock version info."""
         return VersionInfo(3, 42, 0)
 
@@ -248,7 +248,7 @@ class MockSyncDriver(SyncDriverAdapterBase):
     def __init__(
         self,
         connection: MockSyncConnection,
-        statement_config: Optional[StatementConfig] = None,
+        statement_config: StatementConfig | None = None,
         driver_features: Optional["dict[str, Any]"] = None,
     ) -> None:
         if statement_config is None:
@@ -260,7 +260,7 @@ class MockSyncDriver(SyncDriverAdapterBase):
                 ),
             )
         super().__init__(connection, statement_config, driver_features)
-        self._data_dictionary: Optional[SyncDataDictionaryBase] = None
+        self._data_dictionary: SyncDataDictionaryBase | None = None
 
     @property
     def data_dictionary(self) -> "SyncDataDictionaryBase":
@@ -286,7 +286,7 @@ class MockSyncDriver(SyncDriverAdapterBase):
         except Exception as e:
             raise SQLSpecError(f"Mock database error: {e}") from e
 
-    def _try_special_handling(self, cursor: MockSyncCursor, statement: SQL) -> Optional[Any]:
+    def _try_special_handling(self, cursor: MockSyncCursor, statement: SQL) -> Any | None:
         """Mock special handling - always return None."""
         return None
 
@@ -359,7 +359,7 @@ class MockAsyncDriver(AsyncDriverAdapterBase):
     def __init__(
         self,
         connection: MockAsyncConnection,
-        statement_config: Optional[StatementConfig] = None,
+        statement_config: StatementConfig | None = None,
         driver_features: Optional["dict[str, Any]"] = None,
     ) -> None:
         if statement_config is None:
@@ -371,7 +371,7 @@ class MockAsyncDriver(AsyncDriverAdapterBase):
                 ),
             )
         super().__init__(connection, statement_config, driver_features)
-        self._data_dictionary: Optional[AsyncDataDictionaryBase] = None
+        self._data_dictionary: AsyncDataDictionaryBase | None = None
 
     @property
     def data_dictionary(self) -> "AsyncDataDictionaryBase":
@@ -397,7 +397,7 @@ class MockAsyncDriver(AsyncDriverAdapterBase):
         except Exception as e:
             raise SQLSpecError(f"Mock async database error: {e}") from e
 
-    async def _try_special_handling(self, cursor: MockAsyncCursor, statement: SQL) -> Optional[Any]:
+    async def _try_special_handling(self, cursor: MockAsyncCursor, statement: SQL) -> Any | None:
         """Mock async special handling - always return None."""
         return None
 
