@@ -1,6 +1,7 @@
 """Unit tests for ObStoreBackend."""
 
 import tempfile
+from typing import Any
 
 import pytest
 
@@ -210,7 +211,7 @@ def test_write_and_read_arrow() -> None:
         store = ObStoreBackend(f"file://{temp_dir}")
 
         # Create test Arrow table
-        data = {"id": [1, 2, 3], "name": ["Alice", "Bob", "Charlie"], "score": [95.5, 87.0, 92.3]}
+        data: dict[str, Any] = {"id": [1, 2, 3], "name": ["Alice", "Bob", "Charlie"], "score": [95.5, 87.0, 92.3]}
         table = pa.table(data)
 
         store.write_arrow("test_data.parquet", table)
@@ -230,7 +231,7 @@ def test_stream_arrow() -> None:
         store = ObStoreBackend(f"file://{temp_dir}")
 
         # Create test Arrow table
-        data = {"id": [1, 2, 3, 4, 5], "value": ["a", "b", "c", "d", "e"]}
+        data: dict[str, Any] = {"id": [1, 2, 3, 4, 5], "value": ["a", "b", "c", "d", "e"]}
         table = pa.table(data)
 
         store.write_arrow("stream_test.parquet", table)
@@ -409,7 +410,11 @@ async def test_async_write_and_read_arrow() -> None:
         store = ObStoreBackend(f"file://{temp_dir}")
 
         # Create test Arrow table
-        data = {"id": [1, 2, 3, 4], "name": ["Alice", "Bob", "Charlie", "David"], "score": [95.5, 87.0, 92.3, 89.7]}
+        data: dict[str, Any] = {
+            "id": [1, 2, 3, 4],
+            "name": ["Alice", "Bob", "Charlie", "David"],
+            "score": [95.5, 87.0, 92.3, 89.7],
+        }
         table = pa.table(data)
 
         await store.write_arrow_async("async_test_data.parquet", table)
@@ -429,7 +434,7 @@ async def test_async_stream_arrow() -> None:
         store = ObStoreBackend(f"file://{temp_dir}")
 
         # Create test Arrow table
-        data = {"id": [1, 2, 3, 4, 5, 6], "value": ["a", "b", "c", "d", "e", "f"]}
+        data: dict[str, Any] = {"id": [1, 2, 3, 4, 5, 6], "value": ["a", "b", "c", "d", "e", "f"]}
         table = pa.table(data)
 
         await store.write_arrow_async("async_stream_test.parquet", table)
