@@ -1,15 +1,16 @@
 """Tests for sqlspec.utils.type_guards module.
 
 Tests all protocol type guards, validation functions, edge cases, and performance.
-Uses function-based pytest approach as per CLAUDE.md requirements.
+Uses function-based pytest approach as per AGENTS.md requirements.
 """
 
 from dataclasses import dataclass
-from typing import Any, Optional, cast
+from typing import Any, cast
 
 import msgspec
 import pytest
 from sqlglot import exp
+from typing_extensions import TypedDict
 
 from sqlspec.utils.type_guards import (
     dataclass_to_dict,
@@ -57,6 +58,7 @@ from sqlspec.utils.type_guards import (
     is_schema_with_field,
     is_schema_without_field,
     is_string_literal,
+    is_typed_dict,
     schema_dump,
 )
 
@@ -71,7 +73,15 @@ class SampleDataclass:
 
     name: str
     age: int
-    optional_field: "Optional[str]" = None
+    optional_field: "str | None" = None
+
+
+class SampleTypedDict(TypedDict):
+    """Sample TypedDict for testing."""
+
+    name: str
+    age: int
+    optional_field: "str | None"
 
 
 class MockSQLGlotExpression:
@@ -82,11 +92,7 @@ class MockSQLGlotExpression:
     """
 
     def __init__(
-        self,
-        this: Any = _UNSET,
-        expressions: Any = _UNSET,
-        parent: Any = _UNSET,
-        args: "Optional[dict[str, Any]]" = None,
+        self, this: Any = _UNSET, expressions: Any = _UNSET, parent: Any = _UNSET, args: "dict[str, Any] | None" = None
     ) -> None:
         # Only set attributes if they were explicitly provided
         if this is not _UNSET:
@@ -110,11 +116,7 @@ class MockLiteral:
     """Mock literal for testing."""
 
     def __init__(
-        self,
-        this: "Optional[Any]" = None,
-        is_string: bool = False,
-        is_number: bool = False,
-        parent: "Optional[Any]" = None,
+        self, this: "Any | None" = None, is_string: bool = False, is_number: bool = False, parent: "Any | None" = None
     ) -> None:
         if this is not None:
             self.this = this
@@ -129,7 +131,7 @@ class MockLiteral:
 class MockParameterProtocol:
     """Mock parameter with protocol attributes."""
 
-    def __init__(self, style: "Optional[str]" = None, name: "Optional[str]" = None) -> None:
+    def __init__(self, style: "str | None" = None, name: "str | None" = None) -> None:
         if style is not None:
             self.style = style
         if name is not None:
@@ -932,6 +934,31 @@ def test_get_msgspec_rename_config_with_pascal_rename() -> None:
     assert result == "pascal"
 
 
+def test_is_typed_dict_with_typeddict_class() -> None:
+    """Test is_typed_dict returns True for TypedDict classes."""
+    assert is_typed_dict(SampleTypedDict) is True
+
+
+def test_is_typed_dict_with_typeddict_instance() -> None:
+    """Test is_typed_dict returns False for TypedDict instances (they are dicts)."""
+    sample_data: SampleTypedDict = {"name": "test", "age": 25, "optional_field": "value"}
+    assert is_typed_dict(sample_data) is False
+
+
+def test_is_typed_dict_with_non_typeddict() -> None:
+    """Test is_typed_dict returns False for non-TypedDict types."""
+    assert is_typed_dict(dict) is False
+    assert is_typed_dict(SampleDataclass) is False
+    assert is_typed_dict(str) is False
+    assert is_typed_dict(42) is False
+    assert is_typed_dict({}) is False
+
+
+def test_is_typed_dict_with_regular_dict() -> None:
+    """Test is_typed_dict returns False for regular dict instances."""
+    assert is_typed_dict({"key": "value"}) is False
+
+
 def test_get_msgspec_rename_config_without_rename() -> None:
     """Test get_msgspec_rename_config returns None when no rename config."""
     schema_type = MockMsgspecStructWithoutRename
@@ -982,3 +1009,55 @@ def test_get_msgspec_rename_config_performance() -> None:
     for _ in range(100):
         result = get_msgspec_rename_config(schema_type)
         assert result == "camel"
+
+
+def test_supports_arrow_results_with_protocol_implementation() -> None:
+    """Test supports_arrow_results with object implementing SupportsArrowResults."""
+    from sqlspec.utils.type_guards import supports_arrow_results
+
+    class MockDriverWithArrow:
+        def select_to_arrow(
+            self,
+            statement,
+            /,
+            *parameters,
+            statement_config=None,
+            return_format="table",
+            native_only=False,
+            batch_size=None,
+            arrow_schema=None,
+            **kwargs,
+        ):
+            pass
+
+    driver = MockDriverWithArrow()
+    assert supports_arrow_results(driver) is True
+
+
+def test_supports_arrow_results_without_protocol_implementation() -> None:
+    """Test supports_arrow_results with object not implementing protocol."""
+    from sqlspec.utils.type_guards import supports_arrow_results
+
+    class MockDriverWithoutArrow:
+        def execute(self, sql):
+            pass
+
+    driver = MockDriverWithoutArrow()
+    assert supports_arrow_results(driver) is False
+
+
+def test_supports_arrow_results_with_none() -> None:
+    """Test supports_arrow_results with None."""
+    from sqlspec.utils.type_guards import supports_arrow_results
+
+    assert supports_arrow_results(None) is False
+
+
+def test_supports_arrow_results_with_primitive_types() -> None:
+    """Test supports_arrow_results with primitive types."""
+    from sqlspec.utils.type_guards import supports_arrow_results
+
+    assert supports_arrow_results("string") is False
+    assert supports_arrow_results(42) is False
+    assert supports_arrow_results([1, 2, 3]) is False
+    assert supports_arrow_results({"key": "value"}) is False
